<?php

/**
 * Contains methods for adding Colors Customization Panel and all settings under it
 *
 * @package Ayyash
 * @author ThemeRox
 */
class Rox_Customize_Colors {

	public static function register( $wp_customize ) {

		$wp_customize->remove_section( 'colors' );

		$panel_id = 'colors';

		$wp_customize->add_panel( $panel_id, array(
			'priority'       => 10,
			'capability'     => 'edit_theme_options',
			'theme_supports' => '',
			'title'          => 'Colors',
			'description'    => '',
		) );

		/******************
		 * // Global Section
		 *******************/

		$section_id = 'colors_global';

		$wp_customize->add_section( $section_id,
			array(
				'title'      => __( 'Global', 'ayyash' ),
				'priority'   => 35,
				'capability' => 'edit_theme_options',
				'panel'      => $panel_id
			)
		);

		$setting_id = $section_id . '_accent';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'       => __( 'Accent Color', 'ayyash' ),
					'description' => __( 'Used for Links & Buttons', 'ayyash' ),
					'section'     => $section_id,
					'settings'    => $setting_id
				)
			)
		);

		$setting_id = $section_id . '_accent_shade';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'       => __( 'Accent Shade Color', 'ayyash' ),
					'description' => __( 'Used for Links & Buttons hover state', 'ayyash' ),
					'section'     => $section_id,
					'settings'    => $setting_id
				)
			)
		);


		$setting_id = $section_id . '_alt';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'       => __( 'Form Elements Background Color', 'ayyash' ),
					'description' => __( 'Used for Form Elements', 'ayyash' ),
					'section'     => $section_id,
					'settings'    => $setting_id
				)
			)
		);

		$setting_id = $section_id . '_alt_text';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'       => __( 'Form Elements Text Color', 'ayyash' ),
					'description' => __( 'Used for Form Elements', 'ayyash' ),
					'section'     => $section_id,
					'settings'    => $setting_id
				)
			)
		);


		$setting_id = $section_id . '_border';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'       => __( 'Border Color', 'ayyash' ),
					'description' => __( 'Used for Borders for all content elements', 'ayyash' ),
					'section'     => $section_id,
					'settings'    => $setting_id
				)
			)
		);

		$setting_id = $section_id . '_heading';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'       => __( 'Heading Color', 'ayyash' ),
					'description' => __( 'Used for headings - h1 to h6', 'ayyash' ),
					'section'     => $section_id,
					'settings'    => $setting_id
				)
			)
		);


		$setting_id = $section_id . '_text';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'       => __( 'Text Color', 'ayyash' ),
					'description' => __( 'Used for content text', 'ayyash' ),
					'section'     => $section_id,
					'settings'    => $setting_id
				)
			)
		);

		$setting_id = $section_id . '_text_alt';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'       => __( 'Text Alt Color', 'ayyash' ),
					'description' => __( 'Used for post meta & icons', 'ayyash' ),
					'section'     => $section_id,
					'settings'    => $setting_id
				)
			)
		);


		$setting_id = $section_id . '_site_bg';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'       => __( 'Site Background Color', 'ayyash' ),
					'description' => __( 'Used for background color of the site', 'ayyash' ),
					'section'     => $section_id,
					'settings'    => $setting_id
				)
			)
		);


		$setting_id = $section_id . '_content_bg';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'       => __( 'Content Background Color', 'ayyash' ),
					'description' => __( 'Used for background color of the site content', 'ayyash' ),
					'section'     => $section_id,
					'settings'    => $setting_id
				)
			)
		);

        $setting_id = $section_id . '_sticky_bg';

        $wp_customize->add_setting(
            $setting_id,
            array(
                'default'           => rox_get_default( $setting_id ),
                'type'              => 'theme_mod',
                'sanitize_callback' => 'maybe_hash_hex_color',
            )
        );

        $wp_customize->add_control(
            new WP_Customize_Color_Control(
                $wp_customize,
                $setting_id,
                array(
                    'label'       => __( 'Sticky Post Background Color', 'ayyash' ),
                    'description' => __( 'Used for background color of the sticky post archive layout', 'ayyash' ),
                    'section'     => $section_id,
                    'settings'    => $setting_id
                )
            )
        );


		/******************
		 * // Header Section
		 *******************/

		$section_id = 'colors_header';

		$wp_customize->add_section( $section_id,
			array(
				'title'      => __( 'Header', 'ayyash' ),
				'priority'   => 35,
				'capability' => 'edit_theme_options',
				'panel'      => $panel_id
			)
		);

		$setting_id = $section_id . '_bg';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'       => __( 'Background Color', 'ayyash' ),
					'description' => __( 'Header background color', 'ayyash' ),
					'section'     => $section_id,
					'settings'    => $setting_id,
					'show_opacity' => true, // Optional.
				)
			)
		);
		

		$setting_id = $section_id . '_border';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'       => __( 'Border Color', 'ayyash' ),
					'description' => __( 'Header Bottom Border Color', 'ayyash' ),
					'section'     => $section_id,
					'settings'    => $setting_id
				)
			)
		);


		/********************************
		 * // Secondary Header Section
		 *********************************/

		$head_section_id = 'colors_header2';

		// $wp_customize->add_section( $section_id,
		// 	array(
		// 		'title'      => __( 'Secondary Header', 'ayyash' ),
		// 		'priority'   => 35,
		// 		'capability' => 'edit_theme_options',
		// 		'panel'      => $panel_id
		// 	)
		// );

		$setting_id = $section_id . '_second';

		$wp_customize->add_control(
			new Rox_Customize_Misc_Control(
				$wp_customize,
				$setting_id,
				array(
					'section' => $section_id,
					'type'    => 'heading',
					'label'   => __( 'Secondary Header', 'ayyash' )
				)
			)
		);

		$setting_id = $head_section_id . '_bg';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'    => __( 'Background Color', 'ayyash' ),
					'section'  => $section_id,
					'settings' => $setting_id
				)
			)
		);


		$setting_id = $head_section_id . '_text';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'    => __( 'Text Color', 'ayyash' ),
					'section'  => $section_id,
					'settings' => $setting_id
				)
			)
		);


		$setting_id = $head_section_id . '_border_top';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'    => __( 'Top Border Color', 'ayyash' ),
					'section'  => $section_id,
					'settings' => $setting_id
				)
			)
		);

		$setting_id = $head_section_id . '_border_bottom';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'    => __( 'Bottom Border Color', 'ayyash' ),
					'section'  => $section_id,
					'settings' => $setting_id
				)
			)
		);

		$setting_id = $head_section_id . '_sc_si';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'    => __( 'Social Icon Color', 'ayyash' ),
					'section'  => $section_id,
					'settings' => $setting_id
				)
			)
		);

		$setting_id = $head_section_id . '_sc_si_hover';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'    => __( 'Social Icon Hover Color', 'ayyash' ),
					'section'  => $section_id,
					'settings' => $setting_id
				)
			)
		);

		$setting_id = $head_section_id . '_sc_si_hover_bg';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'    => __( 'Social Icon Hover background Color', 'ayyash' ),
					'section'  => $section_id,
					'settings' => $setting_id
				)
			)
		);


		/******************
		 * // Main Menu Section
		 *******************/

		$section_id = 'colors_menu';

		$wp_customize->add_section( $section_id,
			array(
				'title'      => __( 'Main Menu', 'ayyash' ),
				'priority'   => 35,
				'capability' => 'edit_theme_options',
				'panel'      => $panel_id
			)
		);


		$setting_id = $section_id . '_menu_h';

		$wp_customize->add_control(
			new Rox_Customize_Misc_Control(
				$wp_customize,
				$setting_id,
				array(
					'section' => $section_id,
					'type'    => 'heading',
					'label'   => __( 'Menu Items', 'ayyash' )
				)
			)
		);


		$setting_id = $section_id . '_text';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'    => __( 'Text Color', 'ayyash' ),
					// 'description'    => __( 'Header Text Color', 'ayyash' ),
					'section'  => $section_id,
					'settings' => $setting_id
				)
			)
		);


		$setting_id = $section_id . '_hover';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'    => __( 'Text Hover/Focus Color', 'ayyash' ),
					// 'description'    => __( 'Header Text Color', 'ayyash' ),
					'section'  => $section_id,
					'settings' => $setting_id
				)
			)
		);


        $setting_id = $section_id . '_button_bg';

        $wp_customize->add_setting(
            $setting_id,
            array(
                'default'           => rox_get_default( $setting_id ),
                'type'              => 'theme_mod',
                'sanitize_callback' => 'maybe_hash_hex_color',
            )
        );

        $wp_customize->add_control(
            new WP_Customize_Color_Control(
                $wp_customize,
                $setting_id,
                array(
                    'label'    => __( 'Menu Button Bg Color', 'ayyash' ),
                    // 'description'    => __( 'Header Text Color', 'ayyash' ),
                    'section'  => $section_id,
                    'settings' => $setting_id
                )
            )
        );


        $setting_id = $section_id . '_button_bg_hover';

        $wp_customize->add_setting(
            $setting_id,
            array(
                'default'           => rox_get_default( $setting_id ),
                'type'              => 'theme_mod',
                'sanitize_callback' => 'maybe_hash_hex_color',
            )
        );

        $wp_customize->add_control(
            new WP_Customize_Color_Control(
                $wp_customize,
                $setting_id,
                array(
                    'label'    => __( 'Menu Button Bg Hover Color', 'ayyash' ),
                    // 'description'    => __( 'Header Text Color', 'ayyash' ),
                    'section'  => $section_id,
                    'settings' => $setting_id
                )
            )
        );


        $setting_id = $section_id . '_button_text';

        $wp_customize->add_setting(
            $setting_id,
            array(
                'default'           => rox_get_default( $setting_id ),
                'type'              => 'theme_mod',
                'sanitize_callback' => 'maybe_hash_hex_color',
            )
        );

        $wp_customize->add_control(
            new WP_Customize_Color_Control(
                $wp_customize,
                $setting_id,
                array(
                    'label'    => __( 'Menu Button Text Color', 'ayyash' ),
                    // 'description'    => __( 'Header Text Color', 'ayyash' ),
                    'section'  => $section_id,
                    'settings' => $setting_id
                )
            )
        );

        $setting_id = $section_id . '_button_text_hover';

        $wp_customize->add_setting(
            $setting_id,
            array(
                'default'           => rox_get_default( $setting_id ),
                'type'              => 'theme_mod',
                'sanitize_callback' => 'maybe_hash_hex_color',
            )
        );

        $wp_customize->add_control(
            new WP_Customize_Color_Control(
                $wp_customize,
                $setting_id,
                array(
                    'label'    => __( 'Menu Button Text Hover Color', 'ayyash' ),
                    // 'description'    => __( 'Header Text Color', 'ayyash' ),
                    'section'  => $section_id,
                    'settings' => $setting_id
                )
            )
        );


		$setting_id = $section_id . '_menu_sub_h';

		$wp_customize->add_control(
			new Rox_Customize_Misc_Control(
				$wp_customize,
				$setting_id,
				array(
					'section' => $section_id,
					'type'    => 'heading',
					'label'   => __( 'Sub Menu Items', 'ayyash' )
				)
			)
		);

		$setting_id = $section_id . '_sub_bg';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'    => __( 'Background Color', 'ayyash' ),
					// 'description'    => __( 'Header Text Color', 'ayyash' ),
					'section'  => $section_id,
					'settings' => $setting_id
				)
			)
		);


		$setting_id = $section_id . '_sub_border';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'    => __( 'Border Color', 'ayyash' ),
					// 'description'    => __( 'Header Text Color', 'ayyash' ),
					'section'  => $section_id,
					'settings' => $setting_id
				)
			)
		);


		$setting_id = $section_id . '_sub_text';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'    => __( 'Text Color', 'ayyash' ),
					// 'description'    => __( 'Header Text Color', 'ayyash' ),
					'section'  => $section_id,
					'settings' => $setting_id
				)
			)
		);


		$setting_id = $section_id . '_sub_hover';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'    => __( 'Hover/Focus Text Color', 'ayyash' ),
					// 'description'    => __( 'Header Text Color', 'ayyash' ),
					'section'  => $section_id,
					'settings' => $setting_id
				)
			)
		);

		$setting_id = $section_id . '_sub_hover_bg';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'    => __( 'Hover/Focus Background Color', 'ayyash' ),
					// 'description'    => __( 'Header Text Color', 'ayyash' ),
					'section'  => $section_id,
					'settings' => $setting_id
				)
			)
		);


		/******************
		 * // Mobile Menu Colors
		 *******************/

		$setting_id = $section_id . '_mob_sub_h';

		$wp_customize->add_control(
			new Rox_Customize_Misc_Control(
				$wp_customize,
				$setting_id,
				array(
					'section' => $section_id,
					'type'    => 'heading',
					'label'   => __( 'Mobile Menu', 'ayyash' )
				)
			)
		);


		$setting_id = $section_id . '_mob_bg';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'    => __( 'Menu Background Color', 'ayyash' ),
					'section'  => $section_id,
					'settings' => $setting_id
				)
			)
		);

		$setting_id = $section_id . '_color';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'    => __( 'Menu Item Color', 'ayyash' ),
					'section'  => $section_id,
					'settings' => $setting_id
				)
			)
		);

		$setting_id = $section_id . '_mob_hover';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'    => __( 'Hover/Focus Text Color', 'ayyash' ),
					'section'  => $section_id,
					'settings' => $setting_id
				)
			)
		);

		$setting_id = $section_id . '_mob_hover_bg';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'    => __( 'Hover/Focus Background Color', 'ayyash' ),
					'section'  => $section_id,
					'settings' => $setting_id
				)
			)
		);

		$setting_id = $section_id . '_mob_sub_bg';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'    => __( 'Submenu Background Color', 'ayyash' ),
					'section'  => $section_id,
					'settings' => $setting_id
				)
			)
		);

		$setting_id = $section_id . '_mob_border';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'    => __( 'Menu Item Border Color', 'ayyash' ),
					'section'  => $section_id,
					'settings' => $setting_id
				)
			)
		);


		/******************
		 * // Title Container Section
		 *******************/

		$section_id = 'colors_title';

		$wp_customize->add_section( $section_id,
			array(
				'title'      => __( 'Title Container', 'ayyash' ),
				'priority'   => 35,
				'capability' => 'edit_theme_options',
				'panel'      => $panel_id
			)
		);

		$setting_id = $section_id . '_bg';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'    => __( 'Background Color', 'ayyash' ),
					'section'  => $section_id,
					'settings' => $setting_id
				)
			)
		);


		$setting_id = $section_id . '_text';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'    => __( 'Text Color', 'ayyash' ),
					'section'  => $section_id,
					'settings' => $setting_id
				)
			)
		);


		$setting_id = $section_id . '_border';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'    => __( 'Border Color', 'ayyash' ),
					'section'  => $section_id,
					'settings' => $setting_id
				)
			)
		);



        /******************
         * // Footer Top Color
         *******************/

        $section_id = 'colors_footer_top';

        $wp_customize->add_section( $section_id,
            array(
                'title'      => __( 'Footer Top Colors', 'ayyash' ),
                'priority'   => 35,
                'capability' => 'edit_theme_options',
                'panel'      => $panel_id
            )
        );

        $setting_id = $section_id . '_icon';

        $wp_customize->add_setting(
            $setting_id,
            array(
                'default'           => rox_get_default( $setting_id ),
                'type'              => 'theme_mod',
                'sanitize_callback' => 'maybe_hash_hex_color',
            )
        );

        $wp_customize->add_control(
            new WP_Customize_Color_Control(
                $wp_customize,
                $setting_id,
                array(
                    'label'    => __( 'Icon Color', 'ayyash' ),
                    'section'  => $section_id,
                    'settings' => $setting_id
                )
            )
        );

        $setting_id = $section_id . '_title';

        $wp_customize->add_setting(
            $setting_id,
            array(
                'default'           => rox_get_default( $setting_id ),
                'type'              => 'theme_mod',
                'sanitize_callback' => 'maybe_hash_hex_color',
            )
        );

        $wp_customize->add_control(
            new WP_Customize_Color_Control(
                $wp_customize,
                $setting_id,
                array(
                    'label'    => __( 'Title Color', 'ayyash' ),
                    'section'  => $section_id,
                    'settings' => $setting_id
                )
            )
        );

        $setting_id = $section_id . '_desc';

        $wp_customize->add_setting(
            $setting_id,
            array(
                'default'           => rox_get_default( $setting_id ),
                'type'              => 'theme_mod',
                'sanitize_callback' => 'maybe_hash_hex_color',
            )
        );

        $wp_customize->add_control(
            new WP_Customize_Color_Control(
                $wp_customize,
                $setting_id,
                array(
                    'label'    => __( 'Description Color', 'ayyash' ),
                    'section'  => $section_id,
                    'settings' => $setting_id
                )
            )
        );



		/******************
		 * // Footer Section
		 *******************/

		$section_id = 'colors_footer';

		$wp_customize->add_section( $section_id,
			array(
				'title'      => __( 'Footer', 'ayyash' ),
				'priority'   => 35,
				'capability' => 'edit_theme_options',
				'panel'      => $panel_id
			)
		);


		$setting_id = $section_id . '_main';

		$wp_customize->add_control(
			new Rox_Customize_Misc_Control(
				$wp_customize,
				$setting_id,
				array(
					'section' => $section_id,
					'type'    => 'heading',
					'label'   => __( 'Main Footer', 'ayyash' )
				)
			)
		);

		$setting_id = $section_id . '_bg';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'    => __( 'Background Color', 'ayyash' ),
					'section'  => $section_id,
					'settings' => $setting_id
				)
			)
		);

        $setting_id = $section_id . '_top_border';

        $wp_customize->add_setting(
            $setting_id,
            array(
                'default'           => rox_get_default( $setting_id ),
                'type'              => 'theme_mod',
                'sanitize_callback' => 'maybe_hash_hex_color',
            )
        );

        $wp_customize->add_control(
            new WP_Customize_Color_Control(
                $wp_customize,
                $setting_id,
                array(
                    'label'    => __( 'Border Top Color', 'ayyash' ),
                    'section'  => $section_id,
                    'settings' => $setting_id
                )
            )
        );

		$setting_id = $section_id . '_heading';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'    => __( 'Heading Color', 'ayyash' ),
					'section'  => $section_id,
					'settings' => $setting_id
				)
			)
		);


		$setting_id = $section_id . '_text';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'    => __( 'Text Color', 'ayyash' ),
					'section'  => $section_id,
					'settings' => $setting_id
				)
			)
		);


		$setting_id = $section_id . '_link';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'    => __( 'Link Color', 'ayyash' ),
					'section'  => $section_id,
					'settings' => $setting_id
				)
			)
		);


		$setting_id = $section_id . '_link_hover';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'    => __( 'Link Hover Color', 'ayyash' ),
					'section'  => $section_id,
					'settings' => $setting_id
				)
			)
		);


		$setting_id = $section_id . '_border';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'    => __( 'Border Color', 'ayyash' ),
					'section'  => $section_id,
					'settings' => $setting_id
				)
			)
		);


		$setting_id = $section_id . '_second';

		$wp_customize->add_control(
			new Rox_Customize_Misc_Control(
				$wp_customize,
				$setting_id,
				array(
					'section' => $section_id,
					'type'    => 'heading',
					'label'   => __( 'Secondary Footer', 'ayyash' )
				)
			)
		);

		$setting_id = $section_id . '_sc_bg';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'    => __( 'Background Color', 'ayyash' ),
					'section'  => $section_id,
					'settings' => $setting_id
				)
			)
		);

		$setting_id = $section_id . '_sc_text';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'    => __( 'Text Color', 'ayyash' ),
					'section'  => $section_id,
					'settings' => $setting_id
				)
			)
		);

		$setting_id = $section_id . '_sc_link';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'    => __( 'Link Color', 'ayyash' ),
					'section'  => $section_id,
					'settings' => $setting_id
				)
			)
		);

		$setting_id = $section_id . '_sc_link_hover';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'    => __( 'Link Hover Color', 'ayyash' ),
					'section'  => $section_id,
					'settings' => $setting_id
				)
			)
		);


		$setting_id = $section_id . '_sc_si';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'    => __( 'Social Icon Color', 'ayyash' ),
					'section'  => $section_id,
					'settings' => $setting_id
				)
			)
		);

		$setting_id = $section_id . '_sc_si_hover';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'    => __( 'Social Icon Hover Color', 'ayyash' ),
					'section'  => $section_id,
					'settings' => $setting_id
				)
			)
		);

		$setting_id = $section_id . '_sc_si_hover_bg';

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'type'              => 'theme_mod',
				'sanitize_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$setting_id,
				array(
					'label'    => __( 'Social Icon Hover background Color', 'ayyash' ),
					'section'  => $section_id,
					'settings' => $setting_id
				)
			)
		);


	}
}

?>