<?php
/**
 * @package Ayyash
 * @author ThemeRox
 */


/**
 * Contains methods for customizing the theme customization screen.
 *
 * @link http://codex.wordpress.org/Theme_Customization_API
 * @since Pxlrtheme 1.0
 */
class Rox_Customize_Typography {

	public static function register( $wp_customize ) {

		$wp_customize->remove_section( 'colors' );

		$panel_id = 'typography';

		$wp_customize->add_panel( $panel_id, array(
			'priority'       => 10,
			'capability'     => 'edit_theme_options',
			'theme_supports' => '',
			'title'          => 'Typography',
			'description'    => '',
		) );

		/******************
		 * // Subsets Section
		 *******************/

		$section_id = 'typography_options';

		$setting_id = $section_id . '_subsets';

		$wp_customize->add_section( $section_id,
			array(
				'title'      => __( 'Font Options', 'ayyash' ),
				'priority'   => 35,
				'capability' => 'edit_theme_options',
				'panel'      => $panel_id
			)
		);

		$wp_customize->add_setting(
			$setting_id,
			array(
				'default'           => rox_get_default( $setting_id ),
				'sanitize_callback' => 'rox_sanitize_font_subsets'
			)
		);

		$wp_customize->add_control(
			new Rox_Customize_Control_Checkbox_Multiple(
				$wp_customize,
				$setting_id,
				array(
					'section' => $section_id,
					'label'   => __( 'Choose Google Font Subsets', 'ayyash' ),
					'choices' => rox_get_choices( $setting_id )
				)
			)
		);

		/******************
		 * // Global Section
		 *******************/

		$section_id = 'typography_global';

		$wp_customize->add_section( $section_id,
			array(
				'title'      => __( 'Global', 'ayyash' ),
				'priority'   => 35,
				'capability' => 'edit_theme_options',
				'panel'      => $panel_id
			)
		);

		/* Global */
		rox_generate_font_control( $wp_customize, $section_id, __( 'Text', 'ayyash' ), '', true );


		/******************
		 * // Headings Section
		 *******************/

		$section_id = 'typography_heading';

		$wp_customize->add_section( $section_id,
			array(
				'title'      => __( 'Text Headings', 'ayyash' ),
				'priority'   => 35,
				'capability' => 'edit_theme_options',
				'panel'      => $panel_id
			)
		);

		/* H1 */
		rox_generate_font_control( $wp_customize, $section_id, __( 'H1', 'ayyash' ), 'h1' );

		/* H2 */
		rox_generate_font_control( $wp_customize, $section_id, __( 'H2', 'ayyash' ), 'h2' );

		/* H3 */
		rox_generate_font_control( $wp_customize, $section_id, __( 'H3', 'ayyash' ), 'h3' );

		/* H4 */
		rox_generate_font_control( $wp_customize, $section_id, __( 'H4', 'ayyash' ), 'h4' );

		/* H5 */
		rox_generate_font_control( $wp_customize, $section_id, __( 'H5', 'ayyash' ), 'h5' );

		/* H6 */
		rox_generate_font_control( $wp_customize, $section_id, __( 'H6', 'ayyash' ), 'h6' );


		/******************
		 * // Main Menu Section
		 *******************/

		$section_id = 'typography_menu';

		$wp_customize->add_section( $section_id,
			array(
				'title'      => __( 'Main Menu', 'ayyash' ),
				'priority'   => 35,
				'capability' => 'edit_theme_options',
				'panel'      => $panel_id
			)
		);

		/* Menu Items */
		rox_generate_font_control( $wp_customize, $section_id, __( 'Menu Items', 'ayyash' ), '', true, array( 'line_height' ) );


		/* Sub Menu Items */
		rox_generate_font_control( $wp_customize, $section_id, __( 'Sub Menu Items', 'ayyash' ), 'sub' );


		/******************************
		 * // Site Title & Tagline Section
		 *******************************/

		$section_id = 'typography_site';

		$wp_customize->add_section( $section_id,
			array(
				'title'      => __( 'Site Title & Tagline', 'ayyash' ),
				'priority'   => 35,
				'capability' => 'edit_theme_options',
				'panel'      => $panel_id
			)
		);

		/* Site Title */
		rox_generate_font_control( $wp_customize, $section_id, __( 'Site Title', 'ayyash' ), 'title' );

		/* Site Tagline */
		rox_generate_font_control( $wp_customize, $section_id, __( 'Site Tagline', 'ayyash' ), 'tagline' );


		/******************************
		 * // Sidebar
		 *******************************/

		$section_id = 'typography_sidebar';

		$wp_customize->add_section( $section_id,
			array(
				'title'      => __( 'Sidebar', 'ayyash' ),
				'priority'   => 35,
				'capability' => 'edit_theme_options',
				'panel'      => $panel_id
			)
		);

		/* Site Title */
		rox_generate_font_control( $wp_customize, $section_id, __( 'Widget Title', 'ayyash' ), 'title' );

		/* Site Tagline */
		rox_generate_font_control( $wp_customize, $section_id, __( 'Widget Body', 'ayyash' ), 'body' );


		/******************************
		 * // Footer
		 *******************************/

		$section_id = 'typography_footer';

		$wp_customize->add_section( $section_id,
			array(
				'title'      => __( 'Footer', 'ayyash' ),
				'priority'   => 35,
				'capability' => 'edit_theme_options',
				'panel'      => $panel_id
			)
		);

		/* Widget Title */
		rox_generate_font_control( $wp_customize, $section_id, __( 'Widget Title', 'ayyash' ), 'title' );

		/* Widget Body */
		rox_generate_font_control( $wp_customize, $section_id, __( 'Widget Body', 'ayyash' ), 'body' );

		/* Secondary Footer */
		rox_generate_font_control( $wp_customize, $section_id, __( 'Footer Text', 'ayyash' ), 'text' );


	}
}
