<?php
/**
 * Core Function for theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Ayyash
 * @author ThemeRox
 */

/*----------------------------------------------------------------------
 * Adding post type support for the theme
 *----------------------------------------------------------------------*/

add_theme_support('post-formats', array('audio', 'gallery', 'image', 'link', 'quote', 'video'));


/*----------------------------------------------------------------------
 * Adding Body class for multiauthor system
 *----------------------------------------------------------------------*/

function rox_body_classes($classes)
{
    // Adds a class of group-blog to blogs with more than 1 published author.
    if (is_multi_author()) {
        $classes[] = 'group-blog';
    }

    return $classes;
}

add_filter('body_class', 'rox_body_classes');


/*----------------------------------------------------------------------
 * Function for search menu icon
 *----------------------------------------------------------------------*/

if (!function_exists('rox_search_menu_icon')):


    /*
    * Function Name        : rox_search_menu_icon
    * description          : If theme option have enable search it will show search after menu item.
    * Function Hooked      : wp_nav_menu_items
    * Function return Type : Html after nav menu item
    * Function Since       : 1.0.1
    */


    function rox_search_menu_icon($items, $args)
    {
        if (rox_get_mod('layout_header_search') && $args->theme_location === 'primary') {
            $items .= '<li class="menu-item menu-item-type-custom menu-item-object-custom menu-item-has-children dropdown" id="menu-item-search">
                    <a href="#"><i class="ti-search"></i></a>
                    	<ul class="dropdown-menu">
                    		<li>' .
                get_search_form(false)
                . '</li>
                    	</ul>
                	</li>';
        }

        return $items;
    }

endif;


add_filter('wp_nav_menu_items', 'rox_search_menu_icon', 10, 2);

/*----------------------------------------------------------------------
 * Function for mobile menu icon
 *----------------------------------------------------------------------*/

if (!function_exists('rox_mobile_icon')) {
    function rox_mobile_icon()
    {

        /*
        * Function Name        : rox_mobile_icon
        * Description          : Function to show mobile menu , Applied in master head
        * Function Hooked      : rox_master_head
        * Function return Type : html
        * Function Since       : 1.0.0
        */

        $mobile_iocn_grid = rox_get_mod('layout_header_menu_mobileshow');

        switch ($mobile_iocn_grid) {
            case 'sm':
                $mobile_iocn_grid = ' d-block d-md-none';
                break;
            case 'md':
                $mobile_iocn_grid = ' d-block d-lg-none';
                break;
            case 'lg':
                $mobile_iocn_grid = ' d-block d-xl-none';
                break;

            case 'xl':
                $mobile_iocn_grid = ' d-block';
                break;
            default:
                $mobile_iocn_grid = ' d-block d-xl-none';
        };

        ob_start() ?>

        <div id="rox-mobile-icon" class="<?php echo esc_attr($mobile_iocn_grid) ?>">
            <span><i class="ti-menu" aria-hidden="true"></i></span>
        </div>
        <?php
        echo apply_filters('roxtheme_header_filter_mobile_icon', ob_get_clean() );
    }
}


//mobile menu

if (!function_exists('rox_get_mobile_menu')) {
    function rox_get_mobile_menu()
    {

        ob_start();
        if (has_nav_menu('mobile')) {
            wp_nav_menu(array('theme_location' => 'mobile'));
        } else {
            wp_nav_menu(array('theme_location' => 'primary', 'mobile' => true));
        }
        $output = ob_get_clean();
        return $output;
    }
}


/*----------------------------------------------------------------------
 * Right Nav panel
 *----------------------------------------------------------------------*/
if (!function_exists('rox_header_user_account_info')) {
    /*
    * Function Name        : rox_right_nav_panel
    * Description          : Function For Right Panel
    * Function Hooked      : NA
    * Function return Type : html output
    * Function Since       : rox_site
    */
    function rox_header_user_account_info()
    {
        ?>
            <?php if (is_user_logged_in()) { ?>
                <a class="rox-signup hidden-xs" href="<?php echo esc_url( get_permalink( get_option('woocommerce_myaccount_page_id') ) ); ?>"
                   title="<?php esc_html_e('My Account', 'ayyash'); ?>"> <i class="ti-user" aria-hidden="true"></i> <?php esc_html_e('My Account', 'ayyash'); ?></a>
            <?php } else { ?>
                <a class="rox-signup hidden-xs" href="<?php echo esc_url( get_permalink( get_option('woocommerce_myaccount_page_id') ) ); ?>"
                   title="<?php esc_html_e('Login', 'ayyash'); ?>"> <i class="ti-user" aria-hidden="true"></i> <?php esc_html_e('Sign Up / Log In', 'ayyash'); ?></a>
            <?php } ?>

        <?php
    }
}



//Will check and delete future

/*----------------------------------------------------------------------
 * Display or retrieve list of pages with optional home link.
 *----------------------------------------------------------------------*/

if (!function_exists('rox_wp_page_menu')):

    /**
     * Display or retrieve list of pages with optional home link.
     *
     * This function is copied from WP wp_page_menu function to add an extra class as
     * the default WP function has no inbuilt way to achive this without using hacks
     *
     * @return string html menu
     */
    function rox_wp_page_menu($args = array())
    {
        $defaults = array(
            'sort_column' => 'menu_order, post_title',
            'menu_class' => 'menu',
            'echo' => true,
            'link_before' => '',
            'link_after' => ''
        );
        $args = wp_parse_args($args, $defaults);

        /**
         * Filter the arguments used to generate a page-based menu.
         *
         * @since 2.7.0
         *
         * @see wp_page_menu()
         *
         * @param array $args An array of page menu arguments.
         */
        $args = apply_filters('wp_page_menu_args', $args);

        $menu = '';

        $list_args = $args;

        // Show Home in the menu
        if (!empty($args['show_home'])) {
            if (true === $args['show_home'] || '1' === $args['show_home'] || 1 === $args['show_home']) {
                $text = __('Home', 'ayyash');
            } else {
                $text = $args['show_home'];
            }
            $class = '';
            if (is_front_page() && !is_paged()) {
                $class = 'class="current_page_item"';
            }
            $menu .= '<li ' . $class . '><a href="' . home_url('/') . '">' . $args['link_before'] . $text . $args['link_after'] . '</a></li>';

            // If the front page is a page, add it to the exclude list
            if (get_option('show_on_front') == 'page') {
                if (!empty($list_args['exclude'])) {
                    $list_args['exclude'] .= ',';
                } else {
                    $list_args['exclude'] = '';
                }
                $list_args['exclude'] .= get_option('page_on_front');
            }
        }

        $list_args['echo'] = false;
        $list_args['depth'] = 1;
        $list_args['title_li'] = '';
        $menu .= str_replace(array("\r", "\n", "\t"), '', wp_list_pages($list_args));

        if ($menu) {
            $menu = '<ul class="nav navbar-nav">' . $menu . '</ul>';
        }

        $menu = '<div class="' . esc_attr($args['menu_class']) . '">' . $menu . "</div>\n";

        /**
         * Filter the HTML output of a page-based menu.
         *
         * @since 2.7.0
         *
         * @see wp_page_menu()
         *
         * @param string $menu The HTML output.
         * @param array $args An array of arguments.
         */
        $menu = apply_filters('wp_page_menu', $menu, $args);

        if ($args['echo']) {
            var_dump($menu);
        } else {
            return $menu;
        }

        return '';
    }
endif;


/*----------------------------------------------------------------------
 * Blog Favicon for custom favicon
 *----------------------------------------------------------------------*/

if (!function_exists('rox_blog_favicon')):


    /*
    * Function Name        : rox_blog_favicon
    * Description          : Add custom favicon for the theme
    * Function Hooked      : wp_head
    * Function return Type : html
    * Function Since       : 1.0.0
    */


    function rox_blog_favicon()
    {
        $favicon = rox_get_mod('logo_favicon');
        if ($favicon !== ''): ?>
            <link rel="shortcut icon" href="<?php echo esc_url($favicon); ?>"/>
        <?php endif;
    }

endif;

add_action('wp_head', 'rox_blog_favicon');


/*----------------------------------------------------------------------
 * Notice for WooCommerce Shop Page
 *----------------------------------------------------------------------*/
if (class_exists('WooCommerce')) {
    function rox_show_cpt_archive_notice()
    {

        global $post;

        $shop_page_id = wc_get_page_id('shop');

        if ($post && absint($shop_page_id) === absint($post->ID)) {
            ?>
            <div class="notice notice-warning">
                <p><?php _e('If you are in shop page which is selected as WooCommerce archive page then page option will not work. You have to select settings from Customizer', 'ayyash'); ?></p>
            </div>
            <?php
        }
    }

    add_action('admin_notices', 'rox_show_cpt_archive_notice', 100);
}


if( ! function_exists( 'rox_get_product_discount' ) ) {

    function rox_get_product_discount($product_id = NULL, $precision = 0, $return_html = true )
    {

        $product_id = !$product_id ? get_the_ID() : $product_id;
        $product    = wc_get_product($product_id);
        $discount   = 0;

        if ($product instanceof WC_Product) {

            $sale_price = $product->get_sale_price();
            $regular_price = $product->get_regular_price();

            if (!empty($sale_price) && $regular_price > $sale_price) {

                $discount = (($regular_price - $sale_price) / $regular_price) * 100;
                $discount = round($discount, $precision);
            }
        }

        if ($discount > 0) {
            if ($return_html) {
                return apply_filters('rox_filter_rox_product_discount', '<span class="product-discount">' . $discount . '%</span>', $discount, $product->get_id());
            } else return $discount;
        }

        return false;
    }
}


if( ! function_exists( 'rox_get_product_badge' ) ) {

    function rox_get_product_badge($product_id = NULL, $return_html = true, $check = array() )
    {

        $product_id     = !$product_id ? get_the_ID() : $product_id;
        $product        = wc_get_product($product_id);
        $product_tags   = array_map( function($tag_id) { $term = get_term_by( 'id', $tag_id, 'product_tag'); return $term->name; }, $product->get_tag_ids() );

        if( ! $return_html ) return $product_tags;

        ob_start();

        foreach( $product_tags as $tag_name ){

            if( ! empty( $check ) && ! in_array( $tag_name, $check ) ) continue;

            printf( '<span class="product-badge badge-%s">%s</span>', sanitize_title( $tag_name ), $tag_name );
        }

        return apply_filters( 'rox_filter_rox_get_product_badge', ob_get_clean(), $product_id, $product );
    }
}

