<?php
/*----------------------------------------------------------------------
 * Header Related Hook Function which mainly generate html output
 *----------------------------------------------------------------------*/
if ( ! function_exists('rox_skip_links')){
         /*
         * Function Name        : rox_skip_links
         * Function Hooked      : rox_header_skip_links
         * Function return Type : html
         * Function Since       : 1.0.0
         */

    function rox_skip_links(){
        ob_start()
        ?>
        <a class="skip-link screen-reader-text" href="#content"><?php _e('Skip to content', 'ayyash'); ?></a>
    <?php

        $rox_skip_links = ob_get_clean();

        echo apply_filters('rox_header_filter_skip_links', $rox_skip_links);
    }
}


//secondary_head for top bar

if (!function_exists('rox_secondary_head')) {

    /*
    * Function Name        : roxtheme_action_secondary_head
    * Function Hooked      : rox_header_secondary_header
    * Function return Type : html
    * Function Since       : 1.0.0
    */

    function rox_secondary_head()
    {
        $header_container_cls = apply_filters('rox_header_container_cls', rox_get_mod('layout_global_content_layout'));


        if(rox_get_mod('layout_header_secondary')){

            ob_start()
            ?>
            <header id="secondary-head" class="secondary-header" role="banner">
                <div class="<?php echo esc_attr($header_container_cls); ?>">
                    <div class="row">
                        <?php rox_second_header(); ?>
                    </div>
                </div>
            </header>
            <?php

            $roxtheme_secondary_output = ob_get_clean();
            echo apply_filters('rox_header_filter_secondary_head', $roxtheme_secondary_output);
        }else {
            $roxtheme_secondary_output = '';
            echo apply_filters('rox_header_filter_secondary_head', $roxtheme_secondary_output);
        }
    }
}


//master head for main menu

if (!function_exists('rox_master_head')) {

    /*
    * Function Name        : roxtheme_action_master_head
    * Function Hooked      : rox_header_master_header
    * Function return Type : html
    * Function Since       : 1.0.0
    */


    function rox_master_head()
    {
        $header_container_cls = apply_filters('rox_header_container_cls', rox_get_mod('layout_global_content_layout'));
        ob_start() ?>

        <header id="masthead" class="main-header" role="banner">
            <div class="<?php echo esc_attr($header_container_cls); ?>">
                <div class="masthead-wrap clearfix">
                    <?php rox_site_branding(); ?>

                    <?php echo rox_site_menu() ?>

                    <?php echo rox_mobile_icon() ?>

                </div>
            </div>
        </header>

        <?php

        $roxtheme_masterhead_output = ob_get_clean();

        echo apply_filters('rox_header_filter_master_head', $roxtheme_masterhead_output);

    }
}



//Mobile Menu

if (!function_exists('rox_mobile_menu')){
    function rox_mobile_menu(){

        $mobile_menu_container_cls = apply_filters('rox_mobile_menu_container_cls', rox_get_mod('layout_global_content_layout'));

        $mobile_menu_view = rox_get_mod('layout_header_menu_mobileshow');


        switch ($mobile_menu_view){
            case 'sm':
                $mobile_menu_view = ' d-block d-md-none';
                break;
            case 'md':
                $mobile_menu_view = ' d-block d-lg-none';
                break;

            case 'lg':
                $mobile_menu_view = ' d-block d-xl-none';
                break;

            case 'xl':
                $mobile_menu_view = ' d-block';
                break;
            default:
                $mobile_menu_view = ' d-block d-lg-none';
        };

        ob_start()
        ?>
        <div id="navigation-mobile" class="">
            <div class="<?php echo esc_attr($mobile_menu_container_cls) . esc_attr($mobile_menu_view) ?>">

                <div class="row">
                    <div class="col-md-12">
                        <?php echo rox_get_mobile_menu(); ?>
                        <!-- site-mobile-menu -->
                        <?php
                        $roxtheme_menu_search = rox_get_mod('layout_header_search' );
                        if( ! empty( $roxtheme_menu_search ) ) { ?>
                            <form id="mobile-search" action="<?php echo home_url( '/' ); ?>" method="get">
                                <input type="text" name="s" placeholder="<?php _e( 'Search', 'ayyash' ); ?>" />
                                <button type="submit" class="fa fa-search"></button>
                            </form>
                        <?php } ?>
                    </div>
                </div>
            </div>
        </div><!-- /navigation-mobile -->
        
    <?php

        $rox_mobile_menu = ob_get_clean();

        echo apply_filters('rox_header_filter_mobile_menu', $rox_mobile_menu);
    }
}



/*----------------------------------------------------------------------
 * Page Option related Function
 *----------------------------------------------------------------------*/

// Single Page Style Site Layout


if (!function_exists('rox_single_site_layout')) :

    function rox_single_site_layout()
    {
        /*
        * Function Name        : roxtheme_page_site_layout
        * Description          : This function will apply body class if page seting not define by default
        * Function Hooked      : rox_single_option
        * Parameter            : page or post id
        * Function return Type : class
        * Function Since       : 1.0.0
        */

        $site_layout = get_post_meta(get_the_ID(), 'roxtheme_site_layout', true);

        if ($site_layout != 'default' && !empty($site_layout)) {
            if ($site_layout == 'boxed') {


                add_filter('body_class', function ($classes) {

                    if (!empty($key = array_search('wide', $classes))) {
                        unset($classes[$key]);
                    }
                    return array_merge($classes, array('boxed'));
                });
            } else {
                add_filter('body_class', function ($classes) {
                    if (!empty($key = array_search('boxed', $classes))) {
                        unset($classes[$key]);
                    }
                    return array_merge($classes, array('wide'));
                });
            }
        }
    }

endif;


// Secondary Header Enable Disable

if (!function_exists('rox_single_secondary_header')) {
    function rox_single_secondary_header()
    {
        /*
        * Function Name        : rox_single_secondary_header
        * Description          : Remove secondary header for single page or post
        * Function Hooked      : rox_single_option
        * Function return Type : markup for secondary head or remove action
        * Function Since       : 1.0.0
        */
        $secondary_header = get_post_meta(get_the_ID(), 'roxtheme_secondary_header', true);
        if ($secondary_header != 'default' && !empty($secondary_header)) {
            if ($secondary_header == 'enable') {

                function rox_secondary_header()
                {
                    $header_container_cls = apply_filters('rox_header_container_cls', rox_get_mod('layout_global_content_layout')); 

                    ?>
                    <header id="secondary-head" class="secondary-header" role="banner">
                        <div class="<?php echo esc_attr($header_container_cls); ?>">
                            <div class="row">
                                <?php rox_second_header(); ?>
                            </div>
                        </div>
                    </header>
                <?php }

                add_filter('rox_header_filter_secondary_head', 'rox_secondary_header');
            } else {

                remove_action('rox_header_secondary_header', 'rox_secondary_head');
            }
        }
    }
}
// Master header Enable Disable
if (!function_exists('rox_single_master_header')) {
    function rox_single_master_header()
    {


        /*
        * Function Name        : rox_single_master_header
        * Description          : Ensabel / Disable master head for single page
        * Function Hooked      : rox_single_option
        * Function return Type : html header markup
        * Parameter            : post or page id
        * Function Since       : 1.0.0
        */

        $header_option = get_post_meta(get_the_ID(), 'roxtheme_display_header', true);

        if ($header_option != 'default' && !empty($header_option)) {
            if ($header_option == 'disable') {
                remove_action('rox_header_master_header', 'rox_master_head');
            }
        }

    }
}


/*----------------------------------------------------------------------
 * End Of Page Option Related Function
 *----------------------------------------------------------------------*/



/*----------------------------------------------------------------------
 * Footer Related Function which mainly generate footer related output
 *----------------------------------------------------------------------*/

if (!function_exists('rox_footer_top_fn_widget')) {


    /*
    * Function Name        : rox_footer_top_fn_widget
    * Function Hooked      : rox_footer_top_widget
    * Function return Type : html
    * Function Since       : 1.0.0
    */


    function rox_footer_top_fn_widget()
    {
        $footer_top_container_cls = apply_filters('rox_footer_top_container_cls', rox_get_mod('layout_global_content_layout'));
        ob_start()
        ?>
        <div class="roxtheme-row rox-footer-top">
            <div class="<?php echo esc_attr($footer_top_container_cls); ?>">
                <?php dynamic_sidebar('footer-top-widget'); ?>
            </div>
        </div>

        <?php

        $rox_footer_top_fn_widget = ob_get_clean();

        echo apply_filters('rox_footer_top_filter_widget', $rox_footer_top_fn_widget);

    }
}



if (!function_exists('rox_footer_widget')) {


    /*
    * Function Name        : rox_footer_widget
    * Function Hooked      : rox_footer_bottom_widget
    * Function return Type : html
    * Function Since       : 1.0.0
    */


    function rox_footer_widget()
    {
        $footer_container_cls = apply_filters('rox_footer_container_cls', rox_get_mod('layout_global_content_layout'));
        ob_start()
        ?>
        <div class="roxtheme-row main-footer">
            <div class="<?php echo esc_attr($footer_container_cls); ?>">
                <div class="row">
                    <?php dynamic_sidebar('footer-widget'); ?>
                </div>
            </div>
        </div>

        <?php

        $rox_footer_widget = ob_get_clean();

        echo apply_filters('rox_footer_filter_footer_widget', $rox_footer_widget);

    }
}


if (!function_exists('rox_master_footer')) {


    /*
    * Function Name        : rox_master_footer
    * Function Hooked      : rox_footer_master_footer
    * Function return Type : html
    * Function Since       : 1.0.0
    */

    function rox_master_footer()
    {
        $footer_container_cls = apply_filters('rox_footer_container_cls', rox_get_mod('layout_global_content_layout'));
        ob_start()
        ?>
        <footer id="colophon" class="copyright roxtheme-row" role="contentinfo">
            <div class="<?php echo esc_attr($footer_container_cls); ?>">
                <div class="row">
                    <div class="col-md-12 copyright-text">
                        <?php echo apply_filters('rox_footer_copyright_text', rox_get_footer_copyright()); ?>
                    </div>
                    <div class="col-md-12 rox-footer-social-share pt-20">
                        <ul class="list-inline list-unstyled">
                            <?php rox_footer_social_icons() ?>
                        </ul>
                    </div>
                </div>
                <!-- end row -->
            </div>
            <!-- end container -->
        </footer> <!-- end roxtheme-row -->

        <?php

        $rox_master_footer = ob_get_clean();

        echo apply_filters('rox_footer_filter_master_footer', $rox_master_footer);

    }

}


if (!function_exists('rox_go_to_top')) {

    /*
    * Function Name        : rox_go_to_top
    * Function Hooked      : rox_footer_go_to_top
    * Function return Type : html
    * Function Since       : 1.0.0
    */
    
    function rox_go_to_top()
    {
        ob_start() ?>
        <a href="#0" class="cd-top"><i class="ti-angle-up"></i></a>
        <?php

        $rox_go_to_top = ob_get_clean();

        echo apply_filters('rox_footer_filter_go_to_top', $rox_go_to_top);

    }

}



