<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Ayyash
 * @author ThemeRox
 */


if (!function_exists('rox_post_meta')) :


    /**
     * Prints HTML with meta information for the current post-date/time, author & comments.
     */
    function rox_post_meta()
    {
        echo '<time class="post-date updated"><i class="ti-alarm-clock"></i>' . get_the_time(get_option('date_format')) . '</time>';

        echo '<span class="seperator">/</span>';

        echo comments_popup_link(
            __('<i class="ti-comment-alt"></i>&nbsp; No Comments', 'ayyash'),
            __('<i class="ti-comment-alt"></i>&nbsp; 1 Comment', 'ayyash'),
            __('<i class="ti-comment-alt"></i>&nbsp; % Comments', 'ayyash'));

    }
endif;


if (!function_exists('rox_posted_on')) :


    /**
     * Prints HTML with meta information for the current post-date/time and author.
     */
    function rox_posted_on()
    {
        $time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
        if (get_the_time('U') !== get_the_modified_time('U')) {
            $time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
        }

        $time_string = sprintf($time_string,
            esc_attr(get_the_date('c')),
            esc_html(get_the_date()),
            esc_attr(get_the_modified_date('c')),
            esc_html(get_the_modified_date())
        );

        $posted_on = sprintf(
            _x('Posted on %s', 'post date', 'ayyash'),
            '<a href="' . esc_url(get_permalink()) . '" rel="bookmark">' . $time_string . '</a>'
        );

        $byline = sprintf(
            _x('by %s', 'post author', 'ayyash'),
            '<span class="author vcard"><a class="url fn n" href="' . esc_url(get_author_posts_url(get_the_author_meta('ID'))) . '">' . esc_html(get_the_author()) . '</a></span>'
        );

        echo '<span class="posted-on">' . $posted_on . '</span><span class="byline"> ' . $byline . '</span>';

    }
endif;

if (!function_exists('rox_post_read_more')) :


    /**
     * Prints HTML with meta information for the categories, tags and comments.
     */
    function rox_post_read_more()
    {

        echo ' <div class="read-more"><a href="' . get_permalink(get_the_ID()) . '">' . __('Read More', 'ayyash') . ' <i class="ti-angle-double-right"></i></a></div>';

    }
endif;

if (!function_exists('the_archive_title')) :


    /**
     * Shim for `the_archive_title()`.
     *
     * Display the archive title based on the queried object.
     *
     * @todo Remove this function when WordPress 4.3 is released.
     *
     * @param string $before (optional) Optional. Content to prepend to the title. Default empty.
     * @param string $after (optional) Optional. Content to append to the title. Default empty.
     */
    function the_archive_title($before = '', $after = '')
    {
        if (is_category()) {
            $title = sprintf(__('Category: %s', 'ayyash'), single_cat_title('', false));
        } elseif (is_tag()) {
            $title = sprintf(__('Tag: %s', 'ayyash'), single_tag_title('', false));
        } elseif (is_author()) {
            $title = sprintf(__('Author: %s', 'ayyash'), '<span class="vcard author"><span class="fn">' . get_the_author() . '</span></span>');
        } elseif (is_year()) {
            $title = sprintf(__('Year: %s', 'ayyash'), get_the_date(_x('Y', 'yearly archives date format', 'ayyash')));
        } elseif (is_month()) {
            $title = sprintf(__('Month: %s', 'ayyash'), get_the_date(_x('F Y', 'monthly archives date format', 'ayyash')));
        } elseif (is_day()) {
            $title = sprintf(__('Day: %s', 'ayyash'), get_the_date(_x('F j, Y', 'daily archives date format', 'ayyash')));
        } elseif (is_tax('post_format')) {
            if (is_tax('post_format', 'post-format-aside')) {
                $title = _x('Asides', 'post format archive title', 'ayyash');
            } elseif (is_tax('post_format', 'post-format-gallery')) {
                $title = _x('Galleries', 'post format archive title', 'ayyash');
            } elseif (is_tax('post_format', 'post-format-image')) {
                $title = _x('Images', 'post format archive title', 'ayyash');
            } elseif (is_tax('post_format', 'post-format-video')) {
                $title = _x('Videos', 'post format archive title', 'ayyash');
            } elseif (is_tax('post_format', 'post-format-quote')) {
                $title = _x('Quotes', 'post format archive title', 'ayyash');
            } elseif (is_tax('post_format', 'post-format-link')) {
                $title = _x('Links', 'post format archive title', 'ayyash');
            } elseif (is_tax('post_format', 'post-format-status')) {
                $title = _x('Statuses', 'post format archive title', 'ayyash');
            } elseif (is_tax('post_format', 'post-format-audio')) {
                $title = _x('Audio', 'post format archive title', 'ayyash');
            } elseif (is_tax('post_format', 'post-format-chat')) {
                $title = _x('Chats', 'post format archive title', 'ayyash');
            }
        } elseif (is_post_type_archive()) {
            $title = sprintf(__('Archives: %s', 'ayyash'), post_type_archive_title('', false));
        } elseif (is_tax()) {
            $tax = get_taxonomy(get_queried_object()->taxonomy);
            /* translators: 1: Taxonomy singular name, 2: Current taxonomy term */
            $title = sprintf(__('%1$s: %2$s', 'ayyash'), $tax->labels->singular_name, single_term_title('', false));
        } else {
            $title = __('Archives', 'ayyash');
        }

        /**
         * Filter the archive title.
         *
         * @param string $title Archive title to be displayed.
         */
        $title = apply_filters('get_the_archive_title', $title);

        if (!empty($title)) {
            echo esc_attr($before . $title . $after);
        }
    }
endif;

if (!function_exists('the_archive_description')) :


    /**
     * Shim for `the_archive_description()`.
     *
     * Display category, tag, or term description.
     *
     * @todo Remove this function when WordPress 4.3 is released.
     *
     * @param string $before (optional) Optional. Content to prepend to the description. Default empty.
     * @param string $after (optional) Optional. Content to append to the description. Default empty.
     */
    function the_archive_description($before = '', $after = '')
    {
        $description = apply_filters('get_the_archive_description', term_description());

        if (!empty($description)) {

            /**
             * Filter the archive description.
             *
             * @see term_description()
             *
             * @param string $description Archive description to be displayed.
             */
            echo esc_attr($before . $description . $after);
        }
    }
endif;


/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function rox_categorized_blog()
{
    if (false === ($all_the_cool_cats = get_transient('rox_categories'))) {
        // Create an array of all the categories that are attached to posts.
        $all_the_cool_cats = get_categories(array(
            'fields' => 'ids',
            'hide_empty' => 1,
            // We only need to know if there is more than one category.
            'number' => 2,
        ));

        // Count the number of categories that are attached to the posts.
        $all_the_cool_cats = count($all_the_cool_cats);

        set_transient('rox_categories', $all_the_cool_cats);
    }

    if ($all_the_cool_cats > 1) {
        // This blog has more than 1 category so rox_categorized_blog should return true.
        return true;
    } else {
        // This blog has only 1 category so rox_categorized_blog should return false.
        return false;
    }
}


/**
 * Flush out the transients used in rox_categorized_blog.
 */
function rox_category_transient_flusher()
{
    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
        return;
    }
    // Like, beat it. Dig?
    delete_transient('rox_categories');
}

add_action('edit_category', 'rox_category_transient_flusher');
add_action('save_post', 'rox_category_transient_flusher');


if (!function_exists('rox_post_taxonomy')) :


    /**
     * Shim for `rox_post_taxonomy()`.
     *
     * Display category, tag, or term description.
     *
     * @param unknown $view
     */
    function rox_post_taxonomy($view)
    {
        $show_categories = rox_get_mod('layout_' . $view . '_meta-cats');
        $show_tags = rox_get_mod('layout_' . $view . '_meta-tags');
        $category_list = get_the_category_list();
        $tag_list = get_the_tag_list('<ul class="post-tags"><li>', "</li>\n<li>", '</li></ul>'); // Replicates category output
        $taxonomy_output = '';

        // Categories
        if ($show_categories && $category_list) :
            $taxonomy_output .= '%1$s';
        endif;

        // Tags
        if ($show_tags && $tag_list) :
            $taxonomy_output .= '%2$s';
        endif;

        // Output
        printf(
            $taxonomy_output,
            $category_list,
            $tag_list
        );
    }
endif;


if (!function_exists('rox_post_single_navigation')) :

    /**
     * Shim for `the_archive_description()`.
     *
     * Display category, tag, or term description.
     */
    function rox_post_single_navigation()
    {
        global $post;
        ?>
        <div class="pagination post-pagination row">
            <div
                    class="previous col-md-6 col-sm-6"><?php previous_post_link('%link', '<i class="ti-angle-left"></i><div class="text">' . __('Previous Article', 'ayyash') . '</div>'); ?></div>
            <div
                    class="next col-md-6 col-sm-6"><?php next_post_link('%link', '<i class="ti-angle-right"></i><div class="text">' . __('Next Article', 'ayyash') . '</div>'); ?></div>
        </div>
        <?php
    }
endif;

if (!function_exists('rox_post_author_info')) :


    /**
     * Shim for `rox_post_author_info()`.
     *
     * Display category, tag, or term description.
     */
    function rox_post_author_info()
    {
        global $post;
        $auth_info = get_the_author_meta('description');
        ?>
        <div id="about-author" class="clearfix vcard author">
            <h2 class="fn"><?php _e('by ', 'ayyash') ?><?php the_author_posts_link(); ?></h2>

            <div class="avatar">
                <?php echo get_avatar(get_the_author_meta('ID'), 70); ?>
            </div>
            <div class="author-content">
                <?php echo esc_attr($auth_info) ?>
            </div>
        </div>
        <?php
    }

endif;

if (!function_exists('rox_try_sidebar')) :


    /**
     * Displays sidebar if the @position matches the @view sidebar position
     *
     * @param unknown $view
     * @param unknown $position
     */
    function rox_try_sidebar($view, $position)
    {

        /*
        * Function Name        : rox_try_sidebar
        * Description          : This function will check sidebar to load
        * Function Hooked      :
        * Function return Type : sidebar
        * Function Since       : 1.0.0
        */

        $single_sidebar_position = get_post_meta(get_the_ID(), 'roxtheme_content_layout', true);

        $single_sidebar = get_post_meta(get_the_ID(), 'roxtheme_sidebar', true);

        $gb_rox_sidebar_grid = rox_get_mod('layout_global_sidebar_grid');

        if (class_exists('WooCommerce') && (is_post_type_archive('product') == 'true')) {

            $pos = rox_get_mod('woocommerce_shop_archive_layout');

        } elseif (class_exists('WooCommerce') && is_product() == true) {

            $pos = rox_get_mod('woocommerce_single_layout');

        } elseif (class_exists('WooCommerce') && is_cart() == true) {

            $pos = rox_get_mod('woocommerce_cart_sidebar_layout');

        } elseif (class_exists('WooCommerce') && is_checkout() == true) {

            $pos = rox_get_mod('woocommerce_checkout_sidebar_layout');

        } elseif (class_exists('WooCommerce') && is_account_page() == true) {

            $pos = rox_get_mod('woocommerce_myaccount_sidebar_layout');

        }elseif(class_exists('WooCommerce') && is_product_category() == true){

            $pos = rox_get_mod('woocommerce_product_catalog_sidebar_layout');

        } else {

            if ($single_sidebar_position != 'default' && !empty($single_sidebar_position)) {
                $pos = $single_sidebar_position;
            } else {
                $pos = rox_get_mod('layout_' . $view . '_sidebar');
            }
        }

        if ($pos == $position) {

            if ($single_sidebar != 'default' && (!empty($single_sidebar))) {

                ?>

                <div id="secondary" class="widget-area main-sidebar col-md-<?php echo esc_attr($gb_rox_sidebar_grid) ?>"
                     role="complementary">
                    <?php dynamic_sidebar($single_sidebar); ?>
                </div><!-- #secondary -->
                <?php
            } elseif (class_exists('WooCommerce') && is_post_type_archive('product') == true ) {

                if (!empty(rox_get_mod('woocommerce_shop_archive_sidebar')) && rox_get_mod('woocommerce_shop_archive_sidebar') != 'default') {
                    ?>
                    <div id="secondary"
                         class="widget-area main-sidebar col-md-<?php echo esc_attr($gb_rox_sidebar_grid) ?>"
                         role="complementary">
                        <?php dynamic_sidebar(rox_get_mod('woocommerce_shop_archive_sidebar')) ?>
                    </div><!-- #secondary -->
                    <?php
                } else {
                    get_sidebar();
                }
            } elseif (class_exists('WooCommerce') && is_product() == true) {

                if (!empty(rox_get_mod('woocommerce_single_sidebar')) && rox_get_mod('woocommerce_single_sidebar') != 'default') {
                    ?>
                    <div id="secondary"
                         class="widget-area main-sidebar col-md-<?php echo esc_attr($gb_rox_sidebar_grid) ?>"
                         role="complementary">
                        <?php dynamic_sidebar(rox_get_mod('woocommerce_single_sidebar')) ?>
                    </div><!-- #secondary -->
                    <?php
                } else {
                    get_sidebar();
                }

                ?>
                <div id="secondary" class="widget-area main-sidebar col-md-<?php echo esc_attr($gb_rox_sidebar_grid) ?>"
                     role="complementary">
                    <?php dynamic_sidebar($single_sidebar); ?>
                </div><!-- #secondary -->
                <?php
            } elseif (class_exists('WooCommerce') && is_cart() == true) {

                if (!empty(rox_get_mod('woocommerce_cart_sidebar')) && rox_get_mod('woocommerce_cart_sidebar') != 'default') {
                    ?>
                    <div id="secondary"
                         class="widget-area main-sidebar col-md-<?php echo esc_attr($gb_rox_sidebar_grid) ?>"
                         role="complementary">
                        <?php dynamic_sidebar(rox_get_mod('woocommerce_cart_sidebar')) ?>
                    </div><!-- #secondary -->
                    <?php
                } else {
                    get_sidebar();
                }

                ?>
                <div id="secondary" class="widget-area main-sidebar col-md-<?php echo esc_attr($gb_rox_sidebar_grid) ?>"
                     role="complementary">
                    <?php dynamic_sidebar($single_sidebar); ?>
                </div><!-- #secondary -->
                <?php
            } elseif (class_exists('WooCommerce') && is_checkout() == true){

                if (!empty(rox_get_mod('woocommerce_checkout_sidebar')) && rox_get_mod('woocommerce_checkout_sidebar') != 'default') {
                    ?>
                    <div id="secondary"
                         class="widget-area main-sidebar col-md-<?php echo esc_attr($gb_rox_sidebar_grid) ?>"
                         role="complementary">
                        <?php dynamic_sidebar(rox_get_mod('woocommerce_checkout_sidebar')) ?>
                    </div><!-- #secondary -->
                    <?php
                } else {
                    get_sidebar();
                }

                ?>
                <div id="secondary" class="widget-area main-sidebar col-md-<?php echo esc_attr($gb_rox_sidebar_grid) ?>"
                     role="complementary">
                    <?php dynamic_sidebar($single_sidebar); ?>
                </div><!-- #secondary -->
                <?php

            }elseif (class_exists('WooCommerce') && is_account_page() == true){

                if (!empty(rox_get_mod('woocommerce_myaccount_sidebar')) && rox_get_mod('woocommerce_myaccount_sidebar') != 'default') {
                    ?>
                    <div id="secondary"
                         class="widget-area main-sidebar col-md-<?php echo esc_attr($gb_rox_sidebar_grid) ?>"
                         role="complementary">
                        <?php dynamic_sidebar(rox_get_mod('woocommerce_myaccount_sidebar')) ?>
                    </div><!-- #secondary -->
                    <?php
                } else {
                    get_sidebar();
                }

                ?>
                <div id="secondary" class="widget-area main-sidebar col-md-<?php echo esc_attr($gb_rox_sidebar_grid) ?>"
                     role="complementary">
                    <?php dynamic_sidebar($single_sidebar); ?>
                </div><!-- #secondary -->
                <?php

            }elseif (class_exists('WooCommerce') && is_product_category() == true){

                if (!empty(rox_get_mod('woocommerce_product_catalog_sidebar')) && rox_get_mod('woocommerce_product_catalog_sidebar') != 'default') {
                    ?>
                    <div id="secondary"
                         class="widget-area main-sidebar col-md-<?php echo esc_attr($gb_rox_sidebar_grid) ?>"
                         role="complementary">
                        <?php dynamic_sidebar(rox_get_mod('woocommerce_product_catalog_sidebar')) ?>
                    </div><!-- #secondary -->
                    <?php
                } else {
                    get_sidebar();
                }

                ?>
                <div id="secondary" class="widget-area main-sidebar col-md-<?php echo esc_attr($gb_rox_sidebar_grid) ?>"
                     role="complementary">
                    <?php dynamic_sidebar($single_sidebar); ?>
                </div><!-- #secondary -->
                <?php
            } else {
                get_sidebar();
            }
        } else {

            if (class_exists('WooCommerce') && (is_post_type_archive('product') == true || is_product_taxonomy() == true || is_account_page() == true || is_checkout() == true || is_cart() == true)) {
                remove_action('woocommerce_sidebar', 'woocommerce_get_sidebar');
            } elseif (class_exists('WooCommerce') && is_product() == true) {
                remove_action('woocommerce_sidebar', 'woocommerce_get_sidebar');
            }
        }
    }

endif;


if (!function_exists('rox_main_cls')) :

    /**
     * Prints the appropriate Bootstrap class for the main content area
     */
    function rox_main_cls()
    {
        $view = rox_get_view();

        $content_grid = rox_get_mod('layout_global_content_grid');

        $single_sidebar_position = get_post_meta(get_the_ID(), 'roxtheme_content_layout', true);

        if (class_exists('WooCommerce') && (is_post_type_archive('product') == 'true')) {

            $pos = rox_get_mod('woocommerce_shop_archive_layout');

        } elseif (class_exists('WooCommerce') && is_product() == true) {

            $pos = rox_get_mod('woocommerce_single_layout');

        } elseif (class_exists('WooCommerce') && is_cart() == true) {

            $pos = rox_get_mod('woocommerce_cart_sidebar_layout');

        } elseif (class_exists('WooCommerce') && is_checkout() == true) {

            $pos = rox_get_mod('woocommerce_checkout_sidebar_layout');

        } elseif (class_exists('WooCommerce') && is_account_page() == true) {

            $pos = rox_get_mod('woocommerce_myaccount_sidebar_layout');

        }elseif(class_exists('WooCommerce') && is_product_category() == true){

            $pos = rox_get_mod('woocommerce_product_catalog_sidebar_layout');

        } else {

            if ($single_sidebar_position != 'default' && !empty($single_sidebar_position)) {
                $pos = $single_sidebar_position;
            } else {
                $pos = rox_get_mod('layout_' . $view . '_sidebar');
            }
        }

        if ($pos == 'none') {
            echo 'col-md-12';
        } else {
            echo 'col-md-' . $content_grid;
        }
    }

endif;


if (!function_exists('rox_title_bar')) :

    /**
     * Prints the Title Bar Container
     *
     * @param unknown $view
     */
    function rox_title_bar($view)
    {
        $title_bar = rox_get_mod('layout_' . $view . '_title-bar');

        $single_title_bar = get_post_meta(get_the_ID(), 'roxtheme_titlebar', true);

        if(empty($single_title_bar)){
            $single_title_bar = 'default';
        }

        if (class_exists('WooCommerce') && is_post_type_archive('product') == true) {

            if (rox_get_mod('woocommerce_shop_archive_title-bar')) : ?>

                <div class="roxtheme-row rox-title-bar" id="title-container">
                    <div
                            class="<?php echo apply_filters('rox_content_container_cls', rox_get_mod('layout_global_content_layout')); ?> title-container">
                        <div class="row">
                            <div class="col-md-6">
                                <h3><?php rox_page_title(); ?></h3>
                            </div>
                            <div class="col-md-6">
                                <?php rox_breadcrumb(); ?>
                            </div>
                        </div>
                    </div>
                </div>

            <?php endif;

        }elseif ( class_exists('WooCommerce') && is_cart() == true) {

            if ((rox_get_mod('woocommerce_cart_title-bar') == 1 && ($single_title_bar == 'default') || $single_title_bar == 'enable')) {

                ?>
                <div class="roxtheme-row rox-title-bar" id="title-container">
                    <div class="<?php echo apply_filters('rox_content_container_cls', rox_get_mod('layout_global_content_layout')); ?> title-container">
                        <div class="row">
                            <div class="col-md-6">
                                <h3><?php rox_page_title(); ?></h3>
                            </div>
                            <div class="col-md-6">
                                <?php rox_breadcrumb(); ?>
                            </div>
                        </div>
                    </div>
                </div>
            <?php } ?>
        <?php } elseif (class_exists('WooCommerce') && is_checkout() == true) {

            if ((rox_get_mod('woocommerce_checkout_title-bar') == 1 &&($single_title_bar == 'default') || $single_title_bar == 'enable')) {
                ?>
                <div class="roxtheme-row rox-title-bar" id="title-container">
                    <div class="<?php echo apply_filters('rox_content_container_cls', rox_get_mod('layout_global_content_layout')); ?> title-container">
                        <div class="row">
                            <div class="col-md-6">
                                <h3><?php rox_page_title(); ?></h3>
                            </div>
                            <div class="col-md-6">
                                <?php rox_breadcrumb(); ?>
                            </div>
                        </div>
                    </div>
                </div>
            <?php } ?>
        <?php }elseif ( class_exists('WooCommerce') && is_account_page() == true) {

            if ((rox_get_mod('woocommerce_myaccount_title-bar') == 1 && ($single_title_bar == 'default') || $single_title_bar == 'enable')) {
                ?>
                <div class="roxtheme-row rox-title-bar" id="title-container">
                    <div class="<?php echo apply_filters('rox_content_container_cls', rox_get_mod('layout_global_content_layout')); ?> title-container">
                        <div class="row">
                            <div class="col-md-6">
                                <h3><?php rox_page_title(); ?></h3>
                            </div>
                            <div class="col-md-6">
                                <?php rox_breadcrumb(); ?>
                            </div>
                        </div>
                    </div>
                </div>
            <?php } ?>
        <?php } elseif ( class_exists('WooCommerce') && is_product_category() == true) {

            if (rox_get_mod('woocommerce_product_catalog_title-bar') == 1 ) {
                ?>
                <div class="roxtheme-row rox-title-bar" id="title-container">
                    <div class="<?php echo apply_filters('rox_content_container_cls', rox_get_mod('layout_global_content_layout')); ?> title-container">
                        <div class="row">
                            <div class="col-md-6">
                                <h3><?php rox_page_title(); ?></h3>
                            </div>
                            <div class="col-md-6">
                                <?php rox_breadcrumb(); ?>
                            </div>
                        </div>
                    </div>
                </div>
            <?php } ?>
        <?php }    elseif ((is_front_page() == true && ($single_title_bar == 'default') || $single_title_bar == 'enable')) {
            ?>
            <div class="roxtheme-row rox-title-bar" id="title-container">
                <div
                        class="<?php echo apply_filters('rox_content_container_cls', rox_get_mod('layout_global_content_layout')); ?> title-container">
                    <div class="row">
                        <div class="col-md-6">
                            <h3><?php rox_page_title(); ?></h3>
                        </div>
                        <div class="col-md-6">
                            <?php rox_breadcrumb(); ?>
                        </div>
                    </div>
                </div>
            </div>

        <?php } elseif (is_home() == true && $title_bar == 1) { ?>
            <div class="roxtheme-row rox-title-bar" id="title-container">
                <div
                        class="<?php echo apply_filters('rox_content_container_cls', rox_get_mod('layout_global_content_layout')); ?> title-container">
                    <div class="row">
                        <div class="col-md-6">
                            <h3><?php rox_page_title(); ?></h3>
                        </div>
                        <div class="col-md-6">
                            <?php rox_breadcrumb(); ?>
                        </div>
                    </div>
                </div>
            </div>

        <?php } else {

            if (($title_bar && $single_title_bar == 'default') || $single_title_bar == 'enable') : ?>
                <div class="roxtheme-row rox-title-bar" id="title-container">
                    <div
                            class="<?php echo apply_filters('rox_content_container_cls', rox_get_mod('layout_global_content_layout')); ?> title-container">
                        <div class="row">
                            <div class="col-md-6">
                                <h3><?php rox_page_title(); ?></h3>
                            </div>
                            <div class="col-md-6">
                                <?php rox_breadcrumb(); ?>
                            </div>
                        </div>
                    </div>
                </div>
            <?php
            endif;
        }
    }

endif;


if (!function_exists('rox_page_title')) :


    /**
     * Prints the Page Title inside the Title Container
     */
    function rox_page_title()
    {

        if ((function_exists('is_woocommerce') && is_woocommerce() && is_product()) || (function_exists('is_bbpress') && is_bbpress())) {
            the_title();
        } else if (function_exists('is_woocommerce') && is_woocommerce()) {
            woocommerce_page_title();
        } else if (is_archive()) {
            single_cat_title();
        } else if (is_home()) {
            echo get_bloginfo('name');
        } else if (is_search()) {
            echo __('Search results for: ', 'ayyash') . get_search_query();
        } else {
            the_title();
        }
    }

endif;


if (!function_exists('rox_comments')) :


    /**
     * Prints the Comments for a page or post
     *
     * @param unknown $comment
     * @param unknown $args
     * @param unknown $depth
     */
    function rox_comments($comment, $args, $depth)
    {

        $GLOBALS['comment'] = $comment;

        if (get_comment_type() == 'pingback' || get_comment_type() == 'trackback'): ?>

            <li class="pingback" id="comment-<?php comment_ID() ?>">
                <article <?php comment_class('clearfix') ?>>
                    <div class="comment-meta">
                        <?php _e('Pingback:', 'ayyash') ?>
                        <?php edit_comment_link() ?>
                    </div>
                    <div class="comment-content">
                        <?php comment_author_link(); ?>
                    </div>
                </article>
            </li>

        <?php elseif (get_comment_type() == 'comment'): ?>

            <li id="comment-<?php comment_ID() ?>">
                <article <?php comment_class('clearfix') ?>>
                    <div class="avatar">
                        <?php echo get_avatar($comment, 70); ?>
                    </div>
                    <div class="comment-meta">
                        <?php $author_url = get_comment_author_url();
                        if (empty($author_url) || 'http://' == $author_url): ?>
                            <i class="fa fa-user"></i>
                            <span class="comment-author"><?php comment_author(); ?></span>
                        <?php else: ?>
                            <i class="fa fa-user"></i>
                            <a class="comment-author"
                               href="<?php echo esc_url($author_url); ?>"><?php comment_author(); ?></a>
                        <?php endif; ?>
                        <span class="comment-date post-date"><i
                                    class="fa fa-clock-o"></i><?php comment_date(); ?> <?php _e('at', 'ayyash') ?> <?php comment_time(); ?></span>
                        <span class="comment-reply"> <i class="fa fa-reply"></i>
                            <?php comment_reply_link(array_merge($args, array(
                                'depth' => $depth,
                                'max_depth' => $args['max_depth']
                            ))); ?>
	                    </span>
                    </div>
                    <div class="comment-content">
                        <?php if ($comment->comment_approved == '0'): ?>
                            <p><?php _e('Your comment is awaiting moderation', 'ayyash') ?></p>
                        <?php endif; ?>
                        <?php comment_text(); ?>
                    </div>
                </article>
            </li>
        <?php endif;
    }
endif;

if (!function_exists('rox_custom_comment_fields')) :


    /**
     * Adds the Aria Required attribute for required fields
     */
    function rox_custom_comment_fields()
    {
        $commenter = wp_get_current_commenter();
        $req = get_option('require_name_email');
        $aria_req = ($req ? " aria-required='true'" : ' ');
    }
endif;

add_filter('comment_form_default_fields', 'rox_custom_comment_fields');


if (!function_exists('rox_commentfields_rowtag')) :


    /**
     * Adds the Proper opening markup for comment filed
     *
     * @param unknown $comment_id
     */
    function rox_commentfields_rowtag($comment_id)
    {
        echo '<div class="row">';
    }
endif;

if (!function_exists('rox_commentfields_rowtag_end')) :


    /**
     * Adds the Proper closing markup for comment filed
     *
     * @param unknown $comment_id
     */
    function rox_commentfields_rowtag_end($comment_id)
    {
        echo '</div>';
    }
endif;

add_action('comment_form_before_fields', 'rox_commentfields_rowtag', 10, 1);
add_action('comment_form_after_fields', 'rox_commentfields_rowtag_end', 10, 1);

if (!function_exists('rox_pagination')) :


    /**
     * Prints pagination HTML required by the theme
     */
    function rox_pagination()
    {
        global $wp_query;
        $big = 999999999; // need an unlikely integer
        $pages = paginate_links(array(
            'base' => str_replace($big, '%#%', esc_url(get_pagenum_link($big))),
            'format' => '?paged=%#%',
            'current' => max(1, get_query_var('paged')),
            'total' => $wp_query->max_num_pages,
            'type' => 'array',
            'prev_next' => true,
            'prev_text' => '<i class="ti-angle-left"></i>',
            'next_text' => '<i class="ti-angle-right"></i>',
        ));
        if (is_array($pages)) {
            //$paged = ( get_query_var( 'paged' ) == 0 ) ? 1 : get_query_var( 'paged' );
            echo '<div class="center"><ul class="pagination">';
            foreach ($pages as $page) {
                echo "<li>$page</li>";
            }
            echo '</ul></div>';
        }
    }
endif;

if (!function_exists('rox_breadcrumb')) :


    /**
     * Prints breadcrumb HTML required by the theme
     */
    function rox_breadcrumb()
    {
        global $post;

        if (function_exists('is_woocommerce') && is_woocommerce()) {
            woocommerce_breadcrumb(array(
                'wrap_before' => '<ul class="breadcrumbs">',
                'wrap_after' => '</ul>',
                'delimiter' => '',
                'before' => '<li>',
                'after' => '</li>'
            ));

            return;
        }

        if (function_exists('is_bbpress') && is_bbpress()) {
            echo '<ul class="breadcrumbs">';
            bbp_breadcrumb(array(
                'delimiter' => '',
                'before' => '<li>',
                'after' => '</li>'
            ));
            echo '</ul>';

            return;
        }


        echo '<ul class="breadcrumbs">';

        if (!is_front_page()) {
            echo '<li><a href="';
            echo home_url();
            echo '">' . __('Home', 'ayyash');
            echo "</a></li>";
        }

        if (is_category() || is_single() && !is_singular('portfolio')) {
            $category = get_the_category();
            if (isset($category[0])) {
                echo '<li>' . get_category_parents($category[0]->cat_ID, true, '', false) . '</li>';
            }
        }

        if (is_singular('portfolio')) {
            echo get_the_term_list($post->ID, 'portfolio_category', '<li>', ' - ', '</li>');
        }
        if (is_home()) {
            echo '<li>' . get_option('blog_title', 'Blog') . '</li>';
        }
        if (is_single() || is_page()) {
            echo '<li>' . get_the_title() . '</li>';
        }
        if (is_tag()) {
            echo '<li>' . "Tag: " . single_tag_title('', false) . '</li>';
        }
        if (is_404()) {
            echo '<li>' . __("404 - Page not Found", 'ayyash') . '</li>';
        }
        if (is_search()) {
            echo '<li>' . __("Search", 'ayyash') . '</li>';
        }
        if (is_year()) {
            echo '<li>' . get_the_time('Y') . '</li>';
        }

        echo "</ul>";
    }

endif;

if (!function_exists('rox_footer_social_icons')) :


    /**
     * Prints Footer Social Icons HTML markup
     */
    function rox_footer_social_icons()
    {

        if (!(rox_get_mod('layout_footer_social'))) {
            return;
        }

        $social_profiles = array(
            'social_facebook',
            'social_twitter',
            'social_google',
            'social_linkedin',
            'social_youtube',
            'social_vimeo',
            'social_instagram',
            'social_flickr',
            'social_pinterest',
            'social_dribbble',
            'social_digg',
        );
        $theme_mods = rox_get_mods();
        foreach ($social_profiles as $profile) :
            if (array_key_exists($profile, $theme_mods) && esc_url($theme_mods[$profile]) !== '') :
                $title = ucwords(str_replace('social_', '', $profile));
                ?>
                <li>
                    <a title="<?php echo esc_attr($title); ?>" target="_blank"
                       class="social-icon ti-<?php echo strtolower($title) ?>"
                       href="<?php echo esc_url($theme_mods[$profile]) ?>"></a>
                </li>
            <?php endif;
        endforeach;
    }
endif;

if (!function_exists('rox_header_social_icons')) :


    /**
     * Prints Header Social Icons HTML markup
     */
    function rox_header_social_icons()
    {

        $social_profiles = array(
            'social_facebook',
            'social_twitter',
            'social_google',
            'social_linkedin',
            'social_youtube',
            'social_vimeo',
            'social_instagram',
            'social_flickr',
            'social_pinterest',
            'social_dribbble',
            'social_digg',
        );
        $theme_mods = rox_get_mods();
        foreach ($social_profiles as $profile) :
            if (array_key_exists($profile, $theme_mods) && esc_url($theme_mods[$profile]) !== '') :
                $title = ucwords(str_replace('social_', '', $profile));
                ?>
                <li>
                    <a data-toggle="tooltip" title="<?php echo esc_attr($title); ?>" target="_blank"
                       data-placement="bottom" data-original-title="<?php echo esc_attr($title); ?>"
                       class="social-icon ti-<?php echo strtolower($title) ?>"
                       href="<?php echo esc_url($theme_mods[$profile]) ?>"></a>
                </li>
            <?php endif;
        endforeach;
    }
endif;

if (!function_exists('rox_get_view')):


    /**
     * Determine the current view.
     *
     * @return string    The string representing the current view.
     */
    function rox_get_view()
    {

        // Post types
        $post_types = get_post_types(array('public' => true, '_builtin' => false));
        $post_types[] = 'post';

        // Post parent
        $parent_post_type = '';
        if (is_attachment()) {
            $post_parent = get_post()->post_parent;
            $parent_post_type = get_post_type($post_parent);
        }

        $view = 'post';

        // Blog
        if (is_home()) {
            $view = 'blog';
        } // Archives
        else if (is_archive() && is_post_type_archive('product') != true) {
            $view = 'archive';
        } // Search results
        else if (is_search()) {
            $view = 'search';
        } // Posts and public custom post types
        else if (is_singular($post_types) || (is_attachment() && in_array($parent_post_type, $post_types))) {
            $view = 'post';
        } // Pages
        else if (is_page() || (is_attachment() && 'page' === $parent_post_type)) {
            $view = 'page';
        }

        return $view;
    }
endif;

if (!function_exists('rox_get_footer_copyright')):
    /**
     * Return Pxlrtheme footer copyright text.
     *
     * @return copyright text
     */
    function rox_get_footer_copyright()
    { ?>
        <div class="copy-right text-center">
            <?php echo html_entity_decode(rox_get_mod('layout_footer_footertest')); ?>
        </div>
    <?php }
endif;


if (!function_exists('rox_second_header_icons')) :

    /**
     * Prints markup for Secondary Header Social icons
     *
     */
    function rox_second_header_icons()
    {
        ?>
        <div class="social-icon-container col-md-6">
            <ul>
                <?php rox_header_social_icons(); ?>
            </ul>
        </div>
        <!-- .social-icon-container -->
        <?php
    }
endif;

if (!function_exists('rox_second_header_callout')) :

    /**
     * Prints markup for Secondary Header Callout text
     *
     */
    function rox_second_header_callout()
    {
        ?>
        <div class="callout col-md-6">
            <p>
                <?php echo html_entity_decode(rox_get_mod('layout_header_callout')); ?>
            </p>
        </div>
        <!-- .callout -->
        <?php
    }
endif;

if (!function_exists('rox_second_header_search')) :

    /**
     * Prints markup for Secondary Header Search
     *
     */
    function rox_second_header_search()
    {
        ?>
        <div class="search-form col-md-6">
            <?php get_search_form(); ?>
        </div>
        <!-- .search-form -->
        <?php
    }
endif;


if (!function_exists('rox_second_header')) :

    /**
     * Prints markup for Secondary Header
     *
     */
    function rox_second_header()
    {
        $secondary_layout = explode('_', rox_get_mod('layout_header_secondary_layout'));
        if (count($secondary_layout) !== 2) {
            return;
        }
        foreach ($secondary_layout as $item) {
            $callback = "rox_second_header_$item";
            if (function_exists($callback)) {
                call_user_func($callback);
            }
        }
    }
endif;


if (!function_exists('rox_featured_image_width')) :

    /**
     * Prints CSS width style for featured image
     *
     */
    function rox_featured_image_width($view)
    {
        global $post;

        $img_width = '';

        if (!rox_get_mod('layout_' . $view . '_ft-img-enlarge') && !rox_get_mod('layout_' . $view . '_ft-img-hide') && has_post_thumbnail()) {
            $featured_image = wp_get_attachment_metadata(get_post_thumbnail_id($post->ID, 'blog-normal'), true);
            $width = $featured_image['width'] >= 1140 ? 1140 : $featured_image['width'];
            $img_width = "style='width:{$width}px;max-width:100%'";
        }

        return $img_width;
    }
endif;

if (!function_exists('rox_site_branding')) :

    function rox_site_branding()
    {
        ?>
        <div class="site-branding float-left">

            <?php
            $logo = rox_get_mod('logo_logo');
            $logo_retina = rox_get_mod('logo_logo_retina');
            $logo_retina = $logo_retina === '' ? $logo : $logo_retina;
            if ($logo !== ''): ?>
                <div class="logo">
                    <a href="<?php echo esc_url(home_url()); ?>">
                        <img class="normal" src="<?php echo esc_url($logo); ?>"
                             alt="<?php bloginfo('name') ?> | <?php bloginfo('description') ?>">
                        <img class="retina" src="<?php echo esc_url($logo_retina); ?>"
                             alt="<?php bloginfo('name') ?> | <?php bloginfo('description') ?>">
                    </a>
                </div>
            <?php endif; ?>

            <?php if (!rox_get_mod('title_tagline_hide_title')) : ?>
                <h1 class="site-title"><a href="<?php echo esc_url(home_url('/')); ?>"
                                          rel="home"><?php bloginfo('name'); ?></a></h1>
            <?php endif; ?>

            <?php if (!rox_get_mod('title_tagline_hide_tagline')) : ?>
                <span class="site-description"><?php bloginfo('description'); ?></span>
            <?php endif; ?>
        </div>
        <!-- .site-branding -->
        <?php
    }

endif;