<?php
/**
 * @package Ayyash
 * @author ThemeRox
 */

/*----------------------------------------------------------------------
 * removing After and Before Main Content Hook So we can put our own layout
 *----------------------------------------------------------------------*/

if (!function_exists('rox_woocommerce_init')) :
    function rox_woocommerce_init()
    {

        /*
        * Function Name        : rox_woocommerce_init
        * Description          : Add theme support and remove default action hooks so we can replace them with our own.
        * Function Hooked      : after_setup_theme
        * Function return Type : Void
        * Function Since       : 1.0.0
        */

        add_theme_support('woocommerce');

        // remove default content wrapper
        remove_action('woocommerce_before_main_content', 'woocommerce_output_content_wrapper');
        remove_action('woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end');

    }
endif;


/*----------------------------------------------------------------------
 * Writing After and Before Main Content Hook So we can put our own layout
 *----------------------------------------------------------------------*/

if (!function_exists('rox_woocommerce_before_main_content')) :

    function rox_woocommerce_before_main_content()
    {

        /*
        * Function Name        : rox_woocommerce_before_main_content
        * Description          : Add markup layout before main WooCommerce content.
        * Function Hooked      : woocommerce_before_main_content
        * Function return Type :
        * Function Since       :
        */

        // Begin content wrapper
        ?>
        <div  id="content">
        <?php rox_title_bar(rox_get_view()); ?>
        <div class="roxtheme-row site-content">
        <div class="<?php echo apply_filters('rox_content_container_cls', rox_get_mod('layout_global_content_layout')); ?>">
        <div class="row">

        <?php rox_try_sidebar(rox_get_view(), 'left'); ?>

        <div id="primary" class="content-area <?php rox_main_cls(); ?>">
        <main id="main" class="site-main" role="main">
        <?php
    }
endif;


if (!function_exists('rox_woocommerce_after_main_content')) :

    function rox_woocommerce_after_main_content()
    {

        /*
        * Function Name        : rox_woocommerce_after_main_content
        * Description          : End of the main content wrapper
        * Function Hooked      : woocommerce_after_main_content
        * Function return Type : HTML markup for End content wrapper
        * Function Since       : 1.0.0
        */

        // End content wrapper
        ?>
        </main><!-- #main -->
        </div><!-- #primary -->

        <?php rox_try_sidebar(rox_get_view(), 'right'); ?>

        </div><!-- .row -->
        </div><!-- .container -->
        </div>
        </div><!-- #content -->
        <?php

    }
endif;

/*----------------------------------------------------------------------
 * End of After and Before Main Content Hook So we can put our own layout
 *----------------------------------------------------------------------*/


/*----------------------------------------------------------------------
 * Show number of products Per Page
 *----------------------------------------------------------------------*/

add_filter('loop_shop_per_page', 'roxtheme_loop_shop_per_page', 20);
function roxtheme_loop_shop_per_page($product_number)
{
    $product_number = rox_get_mod('woocommerce_shop_archive_per_page');
    return $product_number;
}

/*----------------------------------------------------------------------
 * Show Title
 *----------------------------------------------------------------------*/

add_filter('woocommerce_show_page_title', 'rox_wc_hide_page_title');

function rox_wc_hide_page_title()
{
    if (rox_get_mod('woocommerce_shop_archive_title') == 1) {
        return true;
    } else {
        return false;
    }
}

/*----------------------------------------------------------------------
 * Remove Shop Page Breadcrumbs as we have default
 *----------------------------------------------------------------------*/

add_filter('init', 'rox_remove_wc_breadcrumbs');

function rox_remove_wc_breadcrumbs()
{
    remove_action('woocommerce_before_main_content', 'woocommerce_breadcrumb', 20, 0);
}


/*----------------------------------------------------------------------
 * Remove Shop Filter
 *----------------------------------------------------------------------*/

add_action('woocommerce_before_shop_loop', 'rox_wc_remove_result_count');

function rox_wc_remove_result_count()
{
    if (rox_get_mod('woocommerce_shop_archive_result_count') == 0) {
        remove_action('woocommerce_before_shop_loop', 'woocommerce_result_count', 20);
    } else {
        add_action('woocommerce_before_shop_loop', 'woocommerce_result_count', 20);
    }

}


/*----------------------------------------------------------------------
 * Remove Shop Page Filter
 *----------------------------------------------------------------------*/

add_action('woocommerce_before_shop_loop', 'rox_wc_remove_archive_short', 12);

function rox_wc_remove_archive_short()
{
    if (rox_get_mod('woocommerce_shop_archive_sort') == 0) {
        remove_action('woocommerce_before_shop_loop', 'woocommerce_catalog_ordering', 30);
    } else {
        add_action('woocommerce_before_shop_loop', 'woocommerce_catalog_ordering', 30);
    }

}


/*----------------------------------------------------------------------
 * Function Hook For Mini Cart
 *----------------------------------------------------------------------*/

if (!function_exists('rox_mini_cart')):


    /*
    * Function Name        : rox_search_menu_icon
    * description          : If theme option have enable search it will show search after menu item.
    * Function Hooked      : wp_nav_menu_items
    * Function return Type : Html after nam menu item
    * Function Since       : 1.0.0
    */


    function rox_mini_cart($items, $args)
    {



        if (rox_get_mod('layout_header_show_mini_cart') && $args->theme_location === 'primary') {
            $items .= '<li class="header-cart-count menu-item"><a class="header-cart" href="' . wc_get_cart_url() . '"><i class="ti-shopping-cart" aria-hidden="true"></i><span class="bage">' . WC()->cart->get_cart_contents_count() . '</span></a></li>';
        }

        return $items;
    }

endif;

function rox_iconic_cart_count_fragments($fragments)
{
    $fragments['li.header-cart-count'] = '<li class="header-cart-count menu-item"><a class="header-cart" href="' . wc_get_cart_url() . '"><i class="ti-shopping-cart" aria-hidden="true"></i><span class="bage">' . WC()->cart->get_cart_contents_count() . '</span></a></li>';

    return $fragments;

}

add_filter('wp_nav_menu_items', 'rox_mini_cart', 10, 2);
add_filter('woocommerce_add_to_cart_fragments', 'rox_iconic_cart_count_fragments', 10, 1);

/*----------------------------------------------------------------------
* Wishlist
*----------------------------------------------------------------------*/


/*----------------------------------------------------------------------
 * Upselss Hook
 *----------------------------------------------------------------------*/

add_filter('woocommerce_upsell_display_args', 'wc_change_number_related_products');

function wc_change_number_related_products($args)
{

    if (is_product()) {

        $args['posts_per_page'] = rox_get_mod('woocommerce_single_upsells_count');

    } elseif (is_cart()) {

        $args['posts_per_page'] = rox_get_mod('woocommerce_cart_upsells_count');

    }else{
        $args['posts_per_page']=2;
    }
    return $args;
}

/*----------------------------------------------------------------------
 * Related product
 *----------------------------------------------------------------------*/

function rox_woo_related_products_limit()
{
    global $product;

    if (is_product()) {
        $args['posts_per_page'] = rox_get_mod('woocommerce_single_related_item_count');
    } else {
        $args['posts_per_page'] = 4;
    }
    return $args;
}

add_filter('woocommerce_output_related_products_args', 'rox_woo_related_products_limit');


/*----------------------------------------------------------------------
 * Cross Sell Count
 *----------------------------------------------------------------------*/

add_filter('woocommerce_cross_sells_total', 'rox_cart_cross_sell_total');
function rox_cart_cross_sell_total($total) {
    $total = rox_get_mod('woocommerce_cart_cross_sell_count');
    return $total;
}


/*----------------------------------------------------------------------
 * Enable Product Zoom
 *----------------------------------------------------------------------*/

if(rox_get_mod('woocommerce_general_enable_product_zoom')){
    add_theme_support( 'wc-product-gallery-zoom' );
} else {
    remove_theme_support( 'wc-product-gallery-zoom' );
}



/*----------------------------------------------------------------------
 * Enable Product Lightbox
 *----------------------------------------------------------------------*/

if(rox_get_mod('woocommerce_general_enable_product_lightbox')){
    add_theme_support( 'wc-product-gallery-lightbox' );
} else {
    remove_theme_support( 'wc-product-gallery-lightbox' );
}


/*----------------------------------------------------------------------
 * Enable Product Gallery Slider
 *----------------------------------------------------------------------*/

if(rox_get_mod('woocommerce_general_enable_product_gallery_slider')){
    add_theme_support( 'wc-product-gallery-slider' );
} else {
    remove_theme_support( 'wc-product-gallery-slider' );
}



/*----------------------------------------------------------------------
 * WooCommerce Template Override functions
 *----------------------------------------------------------------------*/


//product-content

if ( !function_exists('')){

    function rox_woocommerce_before_shop_loop_item(){
        /*
           * Function Name        : rox_woocommerce_before_shop_loop_item
           * Description          :
           * Function Hooked      : woocommerce_before_shop_loop_item
           * Function return Type : html
           * Function Since       : 1.0.0
           */
        ?>

        <h1>Its a Test</h1>

   <?php }
}

/*----------------------------------------------------------------------
 * STOCK
 *----------------------------------------------------------------------*/


function rox_stock_catalog() {
/*
           * Function Name        : rox_stock_catalog
           * Description          : show product is in stock or out of stock
           * Function Hooked      : woocommerce_before_shop_loop_item
           * Function return Type : html
           * Function Since       : 1.0.0
           */
    global $product;
    if ( $product->is_in_stock() ) {
        echo ' <span class="stock-tag" data-toggle="tooltip" title="Stock: '.$product->get_stock_quantity().'">' . $product->get_stock_quantity() . __( ' in stock', 'ayyash' ) . '</span>';

    } else {
        echo ' <span class="stock-tag" data-toggle="tooltip" title="Stock: '.$product->get_stock_quantity().'">'. __( 'out of stock', 'ayyash' ) .'</span>';
    }
}

/*----------------------------------------------------------------------
 * New Product badge
 *----------------------------------------------------------------------*/
function rox_woocommerce_new_badge( ) {
    /*
               * Function Name        : rox_woocommerce_new_badge
               * Description          : show badge new if product is new
               * Function Hooked      : woocommerce_before_shop_loop_item
               * Function return Type : html
               * Function Since       : 1.0.0
               */
    global $product;
        $postdate 		= get_the_time( 'Y-m-d' ,$product->get_id());			// Post date
        $postdatestamp 	= strtotime( $postdate );			// Timestamped post date
        $newness 		= 10; 	// Newness in days as defined by option
        if ( ( time() - ( 60 * 60 * 24 * $newness ) ) < $postdatestamp ) { // If the product was published within the newness time frame display the new badge
            echo '<div class="label-badge new"><span>' . esc_html__('New', 'ayyash') . '</span></div>';
        }

}
/*----------------------------------------------------------------------
 *
 *----------------------------------------------------------------------*/


function rox_sale_countdown_timer( ) {
    global $product;

    $sale_date = $product->get_date_on_sale_to();

    if( ! $sale_date ) return;

    echo '<div class="roxtheme-countdown offer-time" data-date="' . esc_attr( $sale_date->date('Y/m/d') ) . '"></div>';
}


/**
 * Override theme default specification for product # per row
 */
function loop_columns() {
    $loop_columns = rox_get_mod('woocommerce_shop_archive_column');
    return $loop_columns;
}

add_filter('loop_shop_columns', 'loop_columns', 999);




//Override the_excerpt

function tn_custom_excerpt_length( $length ) {
    $excerpt_length = rox_get_mod('layout_blog_excerpt_length');
    return $excerpt_length;
}
add_filter( 'excerpt_length', 'tn_custom_excerpt_length', 999 );

//sold_out hook added
function rox_display_sold_out_loop_woocommerce() {
    global $product;

    if ( !$product->is_in_stock() ) {
        echo '<span class="soldout">' . __( 'Out Of Stock', 'ayyash' ) . '</span>';
    }
}
add_action( 'woocommerce_before_shop_loop_item_title', 'rox_display_sold_out_loop_woocommerce' );



function rox_filter_product_rating_html( $rating_html ){

    global $rox_products;

    if( ! $rox_products ) return $rating_html;
    if( isset( $rox_products['display_rating'] ) && $rox_products['display_rating'] == 'yes' ) return $rating_html;

    return "";
}


/*----------------------------------------------------------------------
 * Related Product Column Limit
 *----------------------------------------------------------------------*/

add_filter( 'woocommerce_output_related_products_args', 'rox_change_number_related_products', 9999 );

function rox_change_number_related_products( $args ) {
    $args['columns'] = rox_get_mod('woocommerce_single_related_product_column'); // # of columns per row
    return $args;
}


/*----------------------------------------------------------------------
 * Product Gallery Thumb Image Size Resizing
 *----------------------------------------------------------------------*/

add_filter( 'woocommerce_get_image_size_gallery_thumbnail', function( $size ) {
    return array(
        'width'  => 300,
        'height' => 300,
        'crop'   => 0,
    );
} );

