<?php

	defined( 'ABSPATH' ) or die( 'Keep Silent' );


	//-------------------------------------------------------------------------------
	// Override WooCommerce Frontend Javascript
	//-------------------------------------------------------------------------------

	if ( ! function_exists( 'rox_woo_scripts' ) ) {

		function rox_woo_scripts() {

		}

		add_action( 'wp_enqueue_scripts', 'rox_woo_scripts' );
	}

	//-------------------------------------------------------------------------------
	// Color Variation Attribute Options
	//-------------------------------------------------------------------------------

	if ( ! function_exists( 'rox_wc_color_variation_attribute_options' ) ) :

		function rox_wc_color_variation_attribute_options( $args = array() ) {

			$args = wp_parse_args( $args, array(
				'options'          => FALSE,
				'attribute'        => FALSE,
				'product'          => FALSE,
				'selected'         => FALSE,
				'name'             => '',
				'id'               => '',
				'class'            => '',
				'show_option_none' => esc_html__( 'Choose an option', 'ayyash' )
			) );

			$options   = $args[ 'options' ];
			$product   = $args[ 'product' ];
			$attribute = $args[ 'attribute' ];
			$name      = $args[ 'name' ] ? $args[ 'name' ] : 'attribute_' . sanitize_title( $attribute );
			$id        = $args[ 'id' ] ? $args[ 'id' ] : sanitize_title( $attribute ) . $product->get_id();
			$class     = $args[ 'class' ];

			if ( empty( $options ) && ! empty( $product ) && ! empty( $attribute ) ) {
				$attributes = $product->get_variation_attributes();
				$options    = $attributes[ $attribute ];
			}

			echo '<select ' . $id . ' class="' . esc_attr( $class ) . ' hide" name="' . esc_attr( $name ) . '" data-attribute_name="attribute_' . esc_attr( sanitize_title( $attribute ) ) . '">';

			if ( $args[ 'show_option_none' ] ) {
				echo '<option value="">' . esc_html( $args[ 'show_option_none' ] ) . '</option>';
			}

			if ( ! empty( $options ) ) {
				if ( $product && taxonomy_exists( $attribute ) ) {
					// Get terms if this is a taxonomy - ordered. We need the names too.
					$terms = wc_get_product_terms( $product->get_id(), $attribute, array( 'fields' => 'all' ) );

					foreach ( $terms as $term ) {
						if ( in_array( $term->slug, $options ) ) {
							echo '<option value="' . esc_attr( $term->slug ) . '" ' . selected( sanitize_title( $args[ 'selected' ] ), $term->slug, FALSE ) . '>' . apply_filters( 'woocommerce_variation_option_name', $term->name ) . '</option>';
						}
					}
				}
			}

			echo '</select>';

			echo '<ul class="list-inline variable-items-wrapper color-variable-wrapper color-variation">';
			if ( ! empty( $options ) ) {
				if ( $product && taxonomy_exists( $attribute ) ) {
					$terms = wc_get_product_terms( $product->get_id(), $attribute, array( 'fields' => 'all' ) );

					foreach ( $terms as $term ) {
						if ( in_array( $term->slug, $options ) ) {
							$get_term_meta  = get_term_meta( $term->term_id, 'rox_taxonomy_color', TRUE );
							$selected_class = ( sanitize_title( $args[ 'selected' ] ) == $term->slug ) ? 'selected' : '';
							if (!empty($get_term_meta)){
							?>

							<li  data-placement="top"
							    class="variable-item color-variable-item color-variable-item-<?php echo esc_attr($term->slug) ?> <?php echo esc_attr($selected_class) ?>"
							    data-value="<?php echo esc_attr( $term->slug ) ?>"><span class="v-color <?php echo esc_attr($term->slug) ?> " data-toggle="tooltip" title="Color : <?php echo esc_html( $term->name ) ?>" style="background-color:<?php echo esc_attr( $get_term_meta ) ?>;"></span></li>
								<?php }else { ?>
								<li data-placement="top"
									class="variable-item color-variable-item color-variable-item-<?php echo esc_attr($term->slug) ?> <?php echo esc_attr($selected_class) ?>"
									data-value="<?php echo esc_attr($term->slug) ?>" ><span class="v-color <?php echo esc_attr($term->slug) ?> " data-toggle="tooltip" title="Color : <?php echo esc_html( $term->name ) ?>" style="background-color:<?php echo esc_attr($term->slug) ?>;"></span></li>
								<?php
							}
						}
					}
				}
			}
			echo '</ul>';
		}

	endif;



	//-------------------------------------------------------------------------------
	// Image Variation Attribute Options
	//-------------------------------------------------------------------------------

	if ( ! function_exists( 'rox_wc_size_variation_attribute_options' ) ) :

		function rox_wc_size_variation_attribute_options( $args = array() ) {

			$args = wp_parse_args( $args, array(
				'options'          => FALSE,
				'attribute'        => FALSE,
				'product'          => FALSE,
				'selected'         => FALSE,
				'name'             => '',
				'id'               => '',
				'class'            => '',
				'show_option_none' => esc_html__( 'Choose an option','ayyash' )
			) );

			$options   = $args[ 'options' ];
			$product   = $args[ 'product' ];
			$attribute = $args[ 'attribute' ];
			$name      = $args[ 'name' ] ? $args[ 'name' ] : 'attribute_' . sanitize_title( $attribute );
			$id        = $args[ 'id' ] ? $args[ 'id' ] : sanitize_title( $attribute ) . $product->get_id();
			$class     = $args[ 'class' ];

			if ( empty( $options ) && ! empty( $product ) && ! empty( $attribute ) ) {
				$attributes = $product->get_variation_attributes();
				$options    = $attributes[ $attribute ];
			}

			echo '<select ' . $id . ' class="' . esc_attr( $class ) . ' hide" name="' . esc_attr( $name ) . '" data-attribute_name="attribute_' . esc_attr( sanitize_title( $attribute ) ) . '">';

			if ( $args[ 'show_option_none' ] ) {
				echo '<option value="">' . esc_html( $args[ 'show_option_none' ] ) . '</option>';
			}

			if ( ! empty( $options ) ) {
				if ( $product && taxonomy_exists( $attribute ) ) {
					// Get terms if this is a taxonomy - ordered. We need the names too.
					$terms = wc_get_product_terms( $product->get_id(), $attribute, array( 'fields' => 'all' ) );

					foreach ( $terms as $term ) {
						if ( in_array( $term->slug, $options ) ) {
							echo '<option value="' . esc_attr( $term->slug ) . '" ' . selected( sanitize_title( $args[ 'selected' ] ), $term->slug, FALSE ) . '>' . apply_filters( 'woocommerce_variation_option_name', $term->name ) . '</option>';
						}
					}
				}
			}

			echo '</select>';

			echo '<ul class="list-inline variable-items-wrapper image-variable-wrapper size-variation">';
			if ( ! empty( $options ) ) {
				if ( $product && taxonomy_exists( $attribute ) ) {
					$terms = wc_get_product_terms( $product->get_id(), $attribute, array( 'fields' => 'all' ) );

					foreach ( $terms as $term ) {
						if ( in_array( $term->slug, $options ) ) {
							$term_meta  = get_term_meta( $term->term_id, 'rox_taxonomy_size', TRUE );

							//$image          = wp_get_attachment_image_src( $get_term_meta, 'full' );
							$selected_class = ( sanitize_title( $args[ 'selected' ] ) == $term->slug ) ? 'selected' : '';
							if(!empty($term_meta)){
							?>
								<li>
									<span class="v-size" data-toggle="tooltip" title="Size: S">S</span>
								</li>
							<li
							    class="variable-item image-variable-item image-variable-item-<?php echo esc_attr($term->slug) ?> <?php echo esc_attr($selected_class) ?>"
								data-value="<?php echo esc_attr( $term->slug ) ?>"><span class="v-size" data-toggle="tooltip" title="<?php echo esc_html( $term->name ) ?>"><img
										alt="<?php echo esc_html( $term->name ) ?>"
										src="<?php echo esc_url($term_meta['url'])  ?>"></span></li>
								<?php }else{ ?>
								<li
									class="variable-item image-variable-item image-variable-item-<?php echo esc_attr($term->slug) ?> <?php echo esc_attr($selected_class) ?>"
									data-value="<?php echo esc_attr( $term->slug ) ?>">
									<span class="v-size" data-toggle="tooltip"  title="Size : <?php echo esc_html( $term->name ) ?>"><?php echo esc_html( $term->name ) ?></span></li>
							<?php
								}
						}
					}
				}
			}
			echo '</ul>';
		}
	endif;

